@@ -28,7 +28,7 @@ import (
 
 	"gotest.tools/v3/assert"
 
-	"gopkg.in/yaml.v3"
+	"go.yaml.in/yaml/v3"
 )
 
 var emptySum = ""
@@ -626,6 +626,7 @@ partitions:
       - name: root
     preemption:
       enabled: true
+      quotapreemptionenabled: true
   - name: "partition-0"
     queues:
       - name: root
@@ -637,6 +638,7 @@ partitions:
       - name: root
     preemption:
       enabled: false
+      quotapreemptionenabled: false
   - name: "partition-0"
     queues:
       - name: root
@@ -644,15 +646,18 @@ partitions:
 	// validate the config and check after the update
 	conf, err := CreateConfig(data)
 	assert.NilError(t, err, "should expect no error")
-	assert.Assert(t, conf.Partitions[0].Preemption.Enabled == nil, "default should be nil")
+	assert.Assert(t, conf.Partitions[0].Preemption.Enabled == nil, "default preemption should be nil")
+	assert.Assert(t, conf.Partitions[0].Preemption.QuotaPreemptionEnabled == nil, "default quota preemption should be nil")
 
 	conf, err = CreateConfig(dataEnabled)
 	assert.NilError(t, err, "should expect no error")
 	assert.Assert(t, *conf.Partitions[0].Preemption.Enabled, "preemption should be enabled")
+	assert.Assert(t, *conf.Partitions[0].Preemption.QuotaPreemptionEnabled, "quota preemption should be enabled")
 
 	conf, err = CreateConfig(dataDisabled)
 	assert.NilError(t, err, "should expect no error")
 	assert.Assert(t, !*conf.Partitions[0].Preemption.Enabled, "preemption should be disabled")
+	assert.Assert(t, !*conf.Partitions[0].Preemption.QuotaPreemptionEnabled, "quota preemption should be disabled")
 }
 
 func TestParseRule(t *testing.T) {
@@ -2181,3 +2186,53 @@ partitions:
 	_, err = CreateConfig(data)
 	assert.ErrorContains(t, err, "group * max resource map[memory:90000 vcore:100000] of queue leaf is greater than immediate or ancestor parent maximum resource map[memory:10000 vcore:10000000]")
 }
+
+// TestUserGroupResolverConfig: tests the user group resolver configuration
+func TestUserGroupResolverConfig(t *testing.T) {
+	data := `
+partitions:
+  -
+    name: default
+    usergroupresolver:
+      type: ldap
+    placementrules:
+      - name: tag
+        value: namespace
+        create: true
+    queues:
+      - name: root
+        submitacl: '*'
+        properties:
+          application.sort.policy: fifo
+          sample: value2
+`
+	// validate the config and check after the update
+	config, err := CreateConfig(data)
+	assert.NilError(t, err)
+
+	// check if the user group resolver is set correctly
+	assert.Equal(t, "ldap", config.Partitions[0].UserGroupResolver.Type)
+
+	// partition with no user group resolver
+	data = `
+partitions:
+  -
+    name: default
+    placementrules:
+      - name: tag
+        value: namespace
+        create: true
+    queues:
+      - name: root
+        submitacl: '*'
+        properties:
+          application.sort.policy: fifo
+          sample: value2
+`
+	// validate the config and check after the update
+	config, err = CreateConfig(data)
+	assert.NilError(t, err)
+
+	// check if the user group resolver is set to empty
+	assert.Equal(t, "", config.Partitions[0].UserGroupResolver.Type)
+}
