@@ -38,14 +38,17 @@ const (
 	CMEventRingBufferCapacity = PrefixEvent + "ringBufferCapacity" // Ring Buffer Capacity
 	CMMaxEventStreams         = PrefixEvent + "maxStreams"
 	CMMaxEventStreamsPerHost  = PrefixEvent + "maxStreamsPerHost"
+	CMRESTResponseSize        = PrefixEvent + "RESTResponseSize"
 
 	// defaults
 	DefaultHealthCheckInterval     = 30 * time.Second
 	DefaultEventTrackingEnabled    = true
 	DefaultEventRequestCapacity    = 1000
 	DefaultEventRingBufferCapacity = 100000
+	DefaultEventChannelSize        = 100000
 	DefaultMaxStreams              = uint64(100)
 	DefaultMaxStreamsPerHost       = uint64(15)
+	DefaultRESTResponseSize        = uint64(10000)
 )
 
 var ConfigContext *SchedulerConfigContext
