@@ -41,12 +41,16 @@ const (
 	DotReplace       = "_dot_"
 	DefaultPartition = "default"
 
-	ApplicationSortPolicy   = "application.sort.policy"
-	ApplicationSortPriority = "application.sort.priority"
-	PriorityPolicy          = "priority.policy"
-	PriorityOffset          = "priority.offset"
-	PreemptionPolicy        = "preemption.policy"
-	PreemptionDelay         = "preemption.delay"
+	// constants defining the names for properties
+	ApplicationSortPolicy                    = "application.sort.policy"
+	ApplicationSortPriority                  = "application.sort.priority"
+	ApplicationUnschedulableAsksBackoff      = "application.unschedasks.backoff"
+	ApplicationUnschedulableAsksBackoffDelay = "application.unschedasks.backoff.delay"
+	PriorityPolicy                           = "priority.policy"
+	PriorityOffset                           = "priority.offset"
+	PreemptionPolicy                         = "preemption.policy"
+	PreemptionDelay                          = "preemption.delay"
+	QuotaPreemptionDelay                     = "preemption.quota.delay"
 
 	// app sort priority values
 	ApplicationSortPriorityEnabled  = "enabled"
@@ -59,32 +63,40 @@ const (
 	errLastQueueLeaf
 )
 
-type placementPathCheckResult int
-
-// Priority
+// MinPriority and MaxPriority used in offset calculations. K8s uses an int32 value for priorities, internal calculations
+// use int64.
 var MinPriority int32 = math.MinInt32
 var MaxPriority int32 = math.MaxInt32
 
-var DefaultPreemptionDelay = 30 * time.Second
+// DefaultQuotaPreemptionDelay is 0, no quota preemption by default
+var DefaultQuotaPreemptionDelay time.Duration = 0
 
-// A queue can be a username with the dot replaced. Most systems allow a 32 character user name.
+// DefaultPreemptionDelay is 30 seconds, guaranteed resources must be set to trigger preemption
+var DefaultPreemptionDelay = 30 * time.Second
+var DefaultAskBackOffDelay = 30 * time.Second
+
+// QueueNameRegExp to validate the name of a queue.
+// A queue can be a username with the dot replaced. Most systems allow a 32 character username.
 // The queue name must thus allow for at least that length with the replacement of dots.
 var QueueNameRegExp = regexp.MustCompile(`^[a-zA-Z0-9_:#/@-]{1,64}$`)
 
-// User and group name check: systems allow different things POSIX is the base but we need to be lenient and allow more.
-// A username must start with a letter(uppercase or lowercase),
-// followed by any number of letter(uppercase or lowercase), digits, ':', '#', '/', '_', '.', '@', '-', and may end with '$'.
+// UserRegExp to validate a username. Systems allow different things POSIX is the base, but we need to be lenient and allow more.
+// A username must start with a letter(uppercase or lowercase), followed by any number of letter(uppercase or lowercase),
+// digits, ':', '#', '/', '_', '.', '@', '-', and may end with '$'.
+// This supports OIDC compliant names.
 var UserRegExp = regexp.MustCompile(`^[_a-zA-Z][a-zA-Z0-9:#/_.@-]*[$]?$`)
 
-// Groups should have a slightly more restrictive regexp (no # / @ or $ at the end)
+// GroupRegExp is similar to UserRegExp, groups have a slightly more restrictive regexp (no # / @ or $ at the end)
 var GroupRegExp = regexp.MustCompile(`^[_a-zA-Z][a-zA-Z0-9:_.-]*$`)
 
-// all characters that make a name different from a regexp
+// SpecialRegExp matches all characters that make a name different from a regexp
 var SpecialRegExp = regexp.MustCompile(`[\^$*+?()\[{}|]`)
 
-// The rule maps to a go identifier check that regexp only
+// RuleNameRegExp as rule names must map to a go identifier check that regexp only
 var RuleNameRegExp = regexp.MustCompile(`^[_a-zA-Z][a-zA-Z0-9_]*$`)
 
+type placementPathCheckResult int
+
 type placementStaticPath struct {
 	path           string
 	ruleChain      string
@@ -677,7 +689,7 @@ func checkQueues(queue *QueueConfig, level int) error {
 
 func IsQueueNameValid(queueName string) error {
 	if !QueueNameRegExp.MatchString(queueName) {
-		return common.InvalidQueueName
+		return common.ErrorInvalidQueueName
 	}
 	return nil
 }
