@@ -446,20 +446,27 @@ func subNonNegative(left, right *Resource) (*Resource, string) {
 // Types not defined in resource this is called against are considered 0 for Quantity
 // A nil resource is treated as an empty resource (no types defined)
 func (r *Resource) FitIn(smaller *Resource) bool {
-	return r.fitIn(smaller, false)
+	return r.fitIn(smaller, false, false)
 }
 
 // FitInMaxUndef checks if smaller fits in the defined resource
 // Types not defined in resource this is called against are considered the maximum value for Quantity
 // A nil resource is treated as an empty resource (no types defined)
 func (r *Resource) FitInMaxUndef(smaller *Resource) bool {
-	return r.fitIn(smaller, true)
+	return r.fitIn(smaller, true, false)
+}
+
+// FitInActual checks if smaller fits in the defined resource based on the actual values. Negative values too are compared as is.
+// Types not defined in resource this is called against are skipped
+// A nil resource is treated as an empty resource (no types defined)
+func (r *Resource) FitInActual(smaller *Resource) bool {
+	return r.fitIn(smaller, true, true)
 }
 
 // Check if smaller fits in the defined resource
-// Negative values will be treated as 0
+// Negative values will be treated as 0 if actual flag is false. Otherwise, use the value as is and do the comparison later
 // A nil resource is treated as an empty resource, behaviour defined by skipUndef
-func (r *Resource) fitIn(smaller *Resource, skipUndef bool) bool {
+func (r *Resource) fitIn(smaller *Resource, skipUndef bool, actual bool) bool {
 	if r == nil {
 		r = Zero // shadows in the local function not seen by the callers.
 	}
@@ -475,7 +482,9 @@ func (r *Resource) fitIn(smaller *Resource, skipUndef bool) bool {
 		if skipUndef && !ok {
 			continue
 		}
-		largerValue = max(0, largerValue)
+		if !actual {
+			largerValue = max(0, largerValue)
+		}
 		if v > largerValue {
 			return false
 		}
@@ -539,15 +548,29 @@ func getFairShare(allocated, guaranteed, fair *Resource) float64 {
 	return maxShare
 }
 
-// Get the share of each resource quantity when compared to the total
+// GetShares Get the share of each resource quantity when compared to the total
+// resource quantity. Resource type agnostic. Sort shares to order the same based on dominant resource.
+// NOTE: shares can be negative and positive in the current assumptions
+func GetShares(res, total *Resource) []float64 {
+	shares, _ := internalGetShares(res, total)
+	return shares
+}
+
+// GetSharesTypeWise Get the share of each resource quantity when compared to the total
 // resources quantity
 // NOTE: shares can be negative and positive in the current assumptions
-func getShares(res, total *Resource) []float64 {
+func GetSharesTypeWise(res, total *Resource) map[string]float64 {
+	_, sharesTypeWise := internalGetShares(res, total)
+	return sharesTypeWise
+}
+
+func internalGetShares(res, total *Resource) ([]float64, map[string]float64) {
 	// shortcut if the passed in resource to get the share on is nil or empty (sparse)
 	if res == nil || len(res.Resources) == 0 {
-		return make([]float64, 0)
+		return make([]float64, 0), make(map[string]float64)
 	}
 	shares := make([]float64, len(res.Resources))
+	sharesTypeWise := make(map[string]float64, len(res.Resources))
 	idx := 0
 	for k, v := range res.Resources {
 		// no usage then there is no share (skip prevents NaN)
@@ -566,13 +589,18 @@ func getShares(res, total *Resource) []float64 {
 					zap.String("resource key", k),
 					zap.Int64("resource quantity", int64(v)))
 			}
-			shares[idx] = float64(v)
+			share := float64(v)
+			shares[idx] = share
+			sharesTypeWise[k] = share
 			idx++
 			continue
 		}
-		shares[idx] = float64(v) / float64(total.Resources[k])
+		share := float64(v) / float64(total.Resources[k])
+		shares[idx] = share
+		sharesTypeWise[k] = share
+
 		// negative share is logged
-		if shares[idx] < 0 {
+		if shares[idx] < 0 || sharesTypeWise[k] < 0 {
 			log.Log(log.Resources).Debug("share set is negative",
 				zap.String("resource key", k),
 				zap.Int64("resource quantity", int64(v)),
@@ -583,7 +611,7 @@ func getShares(res, total *Resource) []float64 {
 
 	// sort in increasing order, NaN can not be part of the list
 	sort.Float64s(shares)
-	return shares
+	return shares, sharesTypeWise
 }
 
 // Calculate share for left of total and right of total.
@@ -592,8 +620,8 @@ func getShares(res, total *Resource) []float64 {
 // 1 if the left share is larger
 // -1 if the right share is larger
 func CompUsageRatio(left, right, total *Resource) int {
-	lshares := getShares(left, total)
-	rshares := getShares(right, total)
+	lshares := GetShares(left, total)
+	rshares := GetShares(right, total)
 
 	return compareShares(lshares, rshares)
 }
@@ -622,8 +650,8 @@ func CompUsageRatioSeparately(leftAllocated, leftGuaranteed, leftFairMax, rightA
 // highest share for right resource from total.
 // If highest share for the right resource is 0 fairness is 1
 func FairnessRatio(left, right, total *Resource) float64 {
-	lshares := getShares(left, total)
-	rshares := getShares(right, total)
+	lshares := GetShares(left, total)
+	rshares := GetShares(right, total)
 
 	// Get the largest value from the shares
 	lshare := float64(0)
@@ -878,6 +906,21 @@ func StrictlyGreaterThanOrEquals(larger, smaller *Resource) bool {
 // Types defined in smaller that are not in the defined resource are ignored.
 // Two resources that are equal are not considered strictly larger than each other.
 func (r *Resource) StrictlyGreaterThanOnlyExisting(smaller *Resource) bool {
+	return r.internalStrictlyOnlyExisting(smaller, false)
+}
+
+// StrictlyGreaterThanOrEqualsOnlyExisting returns true if all quantities for types in the defined resource are greater than or equals
+// the quantity for the same type in smaller.
+// Types defined in smaller that are not in the defined resource are ignored.
+func (r *Resource) StrictlyGreaterThanOrEqualsOnlyExisting(smaller *Resource) bool {
+	return r.internalStrictlyOnlyExisting(smaller, true)
+}
+
+// internalStrictlyOnlyExisting When doEqualsCheck is false, it returns true if all quantities for types in the defined resource are greater than
+// the quantity for the same type in smaller. When doEqualsCheck is true, it returns true if all quantities for types in the defined resource are greater than
+// or equals the quantity for the same type in smaller.
+// Types defined in smaller that are not in the defined resource are ignored.
+func (r *Resource) internalStrictlyOnlyExisting(smaller *Resource, doEqualsCheck bool) bool {
 	if r == nil {
 		r = Zero
 	}
@@ -888,6 +931,9 @@ func (r *Resource) StrictlyGreaterThanOnlyExisting(smaller *Resource) bool {
 	// keep track of the number of not equal values
 	notEqual := false
 
+	// keep track of the number of equal values
+	equal := false
+
 	// Is larger and smaller completely disjoint?
 	atleastOneResourcePresent := false
 	// Is all resource in larger greater than zero?
@@ -905,6 +951,9 @@ func (r *Resource) StrictlyGreaterThanOnlyExisting(smaller *Resource) bool {
 			if val > v {
 				return false
 			}
+			if val <= v {
+				equal = true
+			}
 			if val != v {
 				notEqual = true
 			}
@@ -915,7 +964,11 @@ func (r *Resource) StrictlyGreaterThanOnlyExisting(smaller *Resource) bool {
 	case smaller.IsEmpty() && !r.IsEmpty():
 		return isAllPositiveInLarger
 	case atleastOneResourcePresent:
-		return notEqual
+		if doEqualsCheck {
+			return equal
+		} else {
+			return notEqual
+		}
 	default:
 		// larger and smaller is completely disjoint. none of the resource match.
 		return !r.IsEmpty() && !smaller.IsEmpty()
