@@ -432,6 +432,73 @@ func TestStrictlyGreaterThanOnlyExisting(t *testing.T) {
 	}
 }
 
+func TestStrictlyGreaterThanOrEqualsOnlyExisting(t *testing.T) {
+	type inputs struct {
+		larger  map[string]Quantity
+		smaller map[string]Quantity
+		sameRef bool
+	}
+	type outputs struct {
+		larger  bool
+		smaller bool
+	}
+	var tests = []struct {
+		caseName string
+		input    inputs
+		expected outputs
+	}{
+		{"Nil check", inputs{nil, nil, false}, outputs{false, false}},
+		{"Positive resource and empty resources", inputs{map[string]Quantity{"first": 10}, map[string]Quantity{}, false}, outputs{true, false}},
+		{"Positive resource and nil resources", inputs{map[string]Quantity{"first": 10}, nil, false}, outputs{true, false}},
+
+		{"Equal Positive resources", inputs{map[string]Quantity{"first": 10}, map[string]Quantity{"first": 10}, false}, outputs{true, true}},
+		{"Different Positive resources", inputs{map[string]Quantity{"first": 10}, map[string]Quantity{"first": 20}, false}, outputs{false, true}},
+		{"Different Positive resources", inputs{map[string]Quantity{"first": 10}, map[string]Quantity{"first": 5}, false}, outputs{true, false}},
+
+		{"Equal Positive resources with extra resource types", inputs{map[string]Quantity{"first": 10}, map[string]Quantity{"first": 10, "sec": 10}, false}, outputs{true, true}},
+		{"Different Positive resources with extra resource types", inputs{map[string]Quantity{"first": 10}, map[string]Quantity{"first": 20, "sec": 10}, false}, outputs{false, true}},
+		{"Different Positive resources with extra resource types", inputs{map[string]Quantity{"first": 10}, map[string]Quantity{"first": 5, "sec": 10}, false}, outputs{true, false}},
+
+		{"Equal Positive resources but completely disjoint", inputs{map[string]Quantity{"first": 10}, map[string]Quantity{"sec": 10}, false}, outputs{true, true}},
+		{"Zero resource and empty resources", inputs{map[string]Quantity{"first": 0}, map[string]Quantity{}, false}, outputs{false, false}},
+		{"Zero resource and nil resources", inputs{map[string]Quantity{"first": 0}, nil, false}, outputs{false, false}},
+
+		{"Negative resource and empty resources", inputs{map[string]Quantity{"first": -10}, map[string]Quantity{}, false}, outputs{false, false}},
+		{"Negative resource and nil resources", inputs{map[string]Quantity{"first": -10}, nil, false}, outputs{false, false}},
+		{"Negative resource and empty resources", inputs{map[string]Quantity{"first": -10, "sec": 10}, map[string]Quantity{}, false}, outputs{false, false}},
+		{"Negative resource and nil resources", inputs{map[string]Quantity{"first": -10, "sec": 10}, nil, false}, outputs{false, false}},
+
+		{"Equal Negative resources", inputs{map[string]Quantity{"first": -10}, map[string]Quantity{"first": -10}, false}, outputs{true, true}},
+		{"Different Negative resources", inputs{map[string]Quantity{"first": -10}, map[string]Quantity{"first": -20}, false}, outputs{true, false}},
+		{"Different Negative resources", inputs{map[string]Quantity{"first": -10}, map[string]Quantity{"first": -5}, false}, outputs{false, true}},
+
+		{"Equal Negative resources with extra resource types", inputs{map[string]Quantity{"first": -10}, map[string]Quantity{"first": -10, "sec": 10}, false}, outputs{true, true}},
+		{"Different Negative resources with extra resource types", inputs{map[string]Quantity{"first": -10}, map[string]Quantity{"first": -20, "sec": 10}, false}, outputs{true, false}},
+		{"Different Negative resources with extra resource types", inputs{map[string]Quantity{"first": -10}, map[string]Quantity{"first": -5, "sec": 10}, false}, outputs{false, true}},
+
+		{"Equal Negative resources but completely disjoint", inputs{map[string]Quantity{"first": -10}, map[string]Quantity{"sec": -10}, false}, outputs{true, true}},
+	}
+	for _, tt := range tests {
+		t.Run(tt.caseName, func(t *testing.T) {
+			var compare, base *Resource
+			if tt.input.larger != nil {
+				compare = NewResourceFromMap(tt.input.larger)
+			}
+			if tt.input.sameRef {
+				base = compare
+			} else {
+				base = NewResourceFromMap(tt.input.smaller)
+			}
+			if result := compare.StrictlyGreaterThanOrEqualsOnlyExisting(base); result != tt.expected.larger {
+				t.Errorf("comapre %v, base %v, got %v, expeceted %v", compare, base, result, tt.expected.larger)
+			}
+			if result := base.StrictlyGreaterThanOrEqualsOnlyExisting(compare); result != tt.expected.smaller {
+				t.Errorf("base %v, compare %v, got %v, expeceted %v", base, compare, result, tt.expected.smaller)
+			}
+		})
+	}
+}
+
 func TestStrictlyGreaterThanOrEquals(t *testing.T) {
 	type inputs struct {
 		larger  map[string]Quantity
@@ -1314,6 +1381,77 @@ func TestFitInSkip(t *testing.T) {
 	}
 }
 
+func TestFitInActual(t *testing.T) {
+	tests := []struct {
+		larger   *Resource
+		smaller  *Resource
+		expected bool
+		message  string
+	}{
+		{
+			larger:   NewResource(),
+			smaller:  &Resource{Resources: map[string]Quantity{"a": 1}},
+			expected: true,
+			message:  "defined resource %+v should fit in empty (skip undefined)",
+		},
+		{
+			larger:   NewResourceFromMap(map[string]Quantity{"a": 5}),
+			smaller:  &Resource{Resources: map[string]Quantity{"a": 1}},
+			expected: true,
+			message:  "fitin smaller resource with value %+v should fit in larger %+v (skip undefined)",
+		},
+		{
+			smaller:  &Resource{Resources: map[string]Quantity{"a": 1}},
+			larger:   &Resource{Resources: map[string]Quantity{"not-in-smaller": 1}},
+			expected: true,
+			message:  "different type in smaller %+v should fit in larger %+v (skip undefined)",
+		},
+		{
+			larger:   &Resource{Resources: map[string]Quantity{"not-in-smaller": 1}},
+			smaller:  &Resource{Resources: map[string]Quantity{"not-in-larger": 1}},
+			expected: true,
+			message:  "different type in smaller %+v should fit in larger %+v (skip undefined)",
+		},
+		{
+			larger:   &Resource{Resources: map[string]Quantity{"a": -10}},
+			smaller:  &Resource{Resources: map[string]Quantity{"a": 0, "b": -10}},
+			expected: false,
+			message:  "fitin smaller resource with zero or neg values %+v should not fit in larger %+v (skip undefined)",
+		},
+		{
+			larger:   &Resource{Resources: map[string]Quantity{"a": -5}},
+			smaller:  &Resource{Resources: map[string]Quantity{"a": 0, "b": 10}},
+			expected: false,
+			message:  "fitin smaller resource with value %+v should not fit in larger %+v (skip undefined)",
+		},
+		{
+			larger:   &Resource{Resources: map[string]Quantity{"a": -5}},
+			smaller:  &Resource{Resources: map[string]Quantity{"a": -4, "b": 10}},
+			expected: false,
+			message:  "fitin smaller resource with lesser neg value %+v should not fit in larger %+v (skip undefined)",
+		},
+		{
+			larger:   &Resource{Resources: map[string]Quantity{"a": -5}},
+			smaller:  &Resource{Resources: map[string]Quantity{"a": -6, "b": 10}},
+			expected: true,
+			message:  "fitin smaller resource with higher neg value %+v should fit in larger %+v (skip undefined)",
+		},
+		{
+			larger:   &Resource{Resources: map[string]Quantity{"a": -5}},
+			smaller:  &Resource{Resources: map[string]Quantity{"a": -5, "b": 10}},
+			expected: true,
+			message:  "fitin smaller resource with equal neg value %+v should fit in larger %+v (skip undefined)",
+		},
+	}
+
+	for _, tc := range tests {
+		t.Run(tc.message, func(t *testing.T) {
+			result := tc.larger.FitInActual(tc.smaller)
+			assert.Equal(t, result, tc.expected, tc.message, tc.smaller, tc.larger)
+		})
+	}
+}
+
 //nolint:funlen // thorough test
 func TestGetFairShare(t *testing.T) {
 	// 0 guarantee should be treated as absence of a gurantee
@@ -1547,7 +1685,7 @@ func TestGetShares(t *testing.T) {
 
 	for _, tc := range tests {
 		t.Run(tc.message, func(t *testing.T) {
-			shares := getShares(tc.res, tc.total)
+			shares := GetShares(tc.res, tc.total)
 			if !reflect.DeepEqual(shares, tc.expected) {
 				t.Errorf("incorrect shares for %s, expected %v got: %v", tc.message, tc.expected, shares)
 			}
