@@ -222,6 +222,10 @@ func (ec *EventSystemImpl) Stop() {
 
 // AddEvent adds an event record to the event system. See the interface for details.
 func (ec *EventSystemImpl) AddEvent(event *si.EventRecord) {
+	if event != nil {
+		event.Message = truncateEventMessage(event.Message)
+	}
+
 	metrics.GetEventMetrics().IncEventsCreated()
 	select {
 	case ec.channel <- event:
@@ -232,6 +236,15 @@ func (ec *EventSystemImpl) AddEvent(event *si.EventRecord) {
 	}
 }
 
+// truncates event message to 1024 characters for k8s compatibility
+func truncateEventMessage(message string) string {
+	const k8sEventMessageLimit = 1024
+	if len(message) <= k8sEventMessageLimit {
+		return message
+	}
+	return message[:k8sEventMessageLimit-3] + "..."
+}
+
 func isTrackingEnabled() bool {
 	return common.GetConfigurationBool(configs.GetConfigMap(), configs.CMEventTrackingEnabled, configs.DefaultEventTrackingEnabled)
 }
