@@ -43,7 +43,7 @@ const (
 
 var resourceUsageRangeBuckets = []string{
 	"[0,10%]",
-	"(10%, 20%]",
+	"(10%,20%]",
 	"(20%,30%]",
 	"(30%,40%]",
 	"(40%,50%]",
@@ -62,9 +62,11 @@ type SchedulerMetrics struct {
 	node                  *prometheus.GaugeVec
 	nodeResourceUsage     map[string]*prometheus.GaugeVec
 	schedulingLatency     prometheus.Histogram
+	schedulingCycle       prometheus.Histogram
 	sortingLatency        *prometheus.HistogramVec
 	tryNodeLatency        prometheus.Histogram
 	tryPreemptionLatency  prometheus.Histogram
+	tryNodeEvaluation     prometheus.Histogram
 	lock                  locking.RWMutex
 }
 
@@ -113,17 +115,28 @@ func InitSchedulerMetrics() *SchedulerMetrics {
 			Namespace: Namespace,
 			Subsystem: SchedulerSubsystem,
 			Name:      "scheduling_latency_milliseconds",
-			Help:      "Latency of the main scheduling routine, in milliseconds.",
-			Buckets:   prometheus.ExponentialBuckets(0.0001, 10, 6), // start from 0.1ms
+			Help:      "Latency of the main scheduling routine, in seconds.",
+			Buckets:   prometheus.ExponentialBuckets(0.0001, 10, 8), // start from 0.1ms
 		},
 	)
+
+	s.schedulingCycle = prometheus.NewHistogram(
+		prometheus.HistogramOpts{
+			Namespace: Namespace,
+			Subsystem: SchedulerSubsystem,
+			Name:      "scheduling_cycle_milliseconds",
+			Help:      "Time taken for a scheduling cycle, in seconds.",
+			Buckets:   prometheus.ExponentialBuckets(0.0001, 10, 8),
+		},
+	)
+
 	s.sortingLatency = prometheus.NewHistogramVec(
 		prometheus.HistogramOpts{
 			Namespace: Namespace,
 			Subsystem: SchedulerSubsystem,
 			Name:      "node_sorting_latency_milliseconds",
-			Help:      "Latency of all nodes sorting, in milliseconds.",
-			Buckets:   prometheus.ExponentialBuckets(0.0001, 10, 6), // start from 0.1ms
+			Help:      "Latency of all nodes sorting, in seconds.",
+			Buckets:   prometheus.ExponentialBuckets(0.0001, 10, 8), // start from 0.1ms
 		}, []string{"level"})
 
 	s.tryNodeLatency = prometheus.NewHistogram(
@@ -131,8 +144,18 @@ func InitSchedulerMetrics() *SchedulerMetrics {
 			Namespace: Namespace,
 			Subsystem: SchedulerSubsystem,
 			Name:      "trynode_latency_milliseconds",
-			Help:      "Latency of node condition checks for container allocations, such as placement constraints, in milliseconds.",
-			Buckets:   prometheus.ExponentialBuckets(0.0001, 10, 6),
+			Help:      "Latency of node condition checks for container allocations, such as placement constraints, in seconds.",
+			Buckets:   prometheus.ExponentialBuckets(0.0001, 10, 8),
+		},
+	)
+
+	s.tryNodeEvaluation = prometheus.NewHistogram(
+		prometheus.HistogramOpts{
+			Namespace: Namespace,
+			Subsystem: SchedulerSubsystem,
+			Name:      "trynode_evaluation_milliseconds",
+			Help:      "Time taken to evaluate nodes for a pod, in seconds.",
+			Buckets:   prometheus.ExponentialBuckets(0.0001, 10, 8),
 		},
 	)
 
@@ -141,8 +164,8 @@ func InitSchedulerMetrics() *SchedulerMetrics {
 			Namespace: Namespace,
 			Subsystem: SchedulerSubsystem,
 			Name:      "trypreemption_latency_milliseconds",
-			Help:      "Latency of preemption condition checks for container allocations, in milliseconds.",
-			Buckets:   prometheus.ExponentialBuckets(0.0001, 10, 6),
+			Help:      "Latency of preemption condition checks for container allocations, in seconds.",
+			Buckets:   prometheus.ExponentialBuckets(0.0001, 10, 8),
 		},
 	)
 
@@ -155,6 +178,8 @@ func InitSchedulerMetrics() *SchedulerMetrics {
 		s.schedulingLatency,
 		s.sortingLatency,
 		s.tryNodeLatency,
+		s.schedulingCycle,
+		s.tryNodeEvaluation,
 		s.tryPreemptionLatency,
 	}
 	for _, metric := range metricsList {
@@ -182,6 +207,10 @@ func (m *SchedulerMetrics) ObserveSchedulingLatency(start time.Time) {
 	m.schedulingLatency.Observe(SinceInSeconds(start))
 }
 
+func (m *SchedulerMetrics) ObserveSchedulingCycle(start time.Time) {
+	m.schedulingCycle.Observe(SinceInSeconds(start))
+}
+
 func (m *SchedulerMetrics) ObserveAppSortingLatency(start time.Time) {
 	m.sortingLatency.WithLabelValues(SortingApp).Observe(SinceInSeconds(start))
 }
@@ -194,6 +223,10 @@ func (m *SchedulerMetrics) ObserveTryNodeLatency(start time.Time) {
 	m.tryNodeLatency.Observe(SinceInSeconds(start))
 }
 
+func (m *SchedulerMetrics) ObserveTryNodeEvaluation(start time.Time) {
+	m.tryNodeEvaluation.Observe(SinceInSeconds(start))
+}
+
 func (m *SchedulerMetrics) ObserveTryPreemptionLatency(start time.Time) {
 	m.tryPreemptionLatency.Observe(SinceInSeconds(start))
 }
