@@ -19,6 +19,7 @@
 package objects
 
 import (
+	"errors"
 	"fmt"
 	"strconv"
 	"time"
@@ -294,10 +295,16 @@ func (a *Allocation) IsReleased() bool {
 }
 
 // SetReleased updates the release status of the allocation.
-func (a *Allocation) SetReleased(released bool) {
+func (a *Allocation) SetReleased(released bool) error {
 	a.Lock()
 	defer a.Unlock()
+	if released {
+		if a.preempted {
+			return errors.New("allocation is already preempted")
+		}
+	}
 	a.released = released
+	return nil
 }
 
 // GetTagsClone returns the copy of the tags for this allocation.
@@ -348,10 +355,21 @@ func (a *Allocation) SetAllocatedResource(allocatedResource *resources.Resource)
 }
 
 // MarkPreempted marks the allocation as preempted.
-func (a *Allocation) MarkPreempted() {
+func (a *Allocation) MarkPreempted() error {
 	a.Lock()
 	defer a.Unlock()
+	if a.released {
+		return errors.New("allocation is already released")
+	}
 	a.preempted = true
+	return nil
+}
+
+// MarkUnPreempted unmarks the allocation as preempted.
+func (a *Allocation) MarkUnPreempted() {
+	a.Lock()
+	defer a.Unlock()
+	a.preempted = false
 }
 
 // IsPreempted returns whether the allocation has been marked for preemption or not.
@@ -481,6 +499,11 @@ func (a *Allocation) SendPreemptedBySchedulerEvent(preemptorAllocKey, preemptorA
 	a.askEvents.SendPreemptedByScheduler(a.allocationKey, a.applicationID, preemptorAllocKey, preemptorAppId, preemptorQueuePath, a.GetAllocatedResource())
 }
 
+// SendPreemptedByQuotaChangeEvent updates the event system with the Quota change preemption event.
+func (a *Allocation) SendPreemptedByQuotaChangeEvent(queuePath string) {
+	a.askEvents.SendPreemptedByQuotaChange(a.allocationKey, a.applicationID, queuePath, a.GetAllocatedResource())
+}
+
 // GetAllocationLog returns a list of log entries corresponding to allocation preconditions not being met.
 func (a *Allocation) GetAllocationLog() []*AllocationLogEntry {
 	a.RLock()
@@ -593,3 +616,7 @@ func (a *Allocation) IsForeign() bool {
 func (a *Allocation) IsPreemptable() bool {
 	return a.preemptable
 }
+
+func (a *Allocation) GetAllocationName() string {
+	return a.tags[siCommon.DomainYuniKorn+siCommon.KeyPodName]
+}
