@@ -47,13 +47,17 @@ import (
 )
 
 var (
-	reservationDelay          = 2 * time.Second
+	reservationDelay       = 2 * time.Second
+	reservationWaitTimeout = 60 * time.Minute
+	// Make it configurable
 	completingTimeout         = 30 * time.Second
 	terminatedTimeout         = 3 * 24 * time.Hour
 	defaultPlaceholderTimeout = 15 * time.Minute
 )
 var initAppLogOnce sync.Once
 var rateLimitedAppLog *log.RateLimitedLogger
+var initReqNodeLogOnce sync.Once
+var rateLimitedReqNodeLog *log.RateLimitedLogger
 
 const (
 	Soft string = "Soft"
@@ -114,6 +118,7 @@ type Application struct {
 	hasPlaceholderAlloc  bool                        // Whether there is at least one allocated placeholder
 	runnableInQueue      bool                        // whether the application is runnable/schedulable in the queue. Default is true.
 	runnableByUserLimit  bool                        // whether the application is runnable/schedulable based on user/group quota. Default is true.
+	backoffDeadline      time.Time                   // no scheduling from this application until this deadline
 
 	rmEventHandler        handler.EventHandler
 	rmID                  string
@@ -325,15 +330,30 @@ func (sa *Application) timeoutStateTimer(expectedState string, event application
 				zap.String("state", sa.stateMachine.Current()))
 			// if the app is completing, but there are placeholders left, first do the cleanup
 			if sa.IsCompleting() && !resources.IsZero(sa.allocatedPlaceholder) {
+				replacing := 0
+				preempted := 0
 				var toRelease []*Allocation
 				for _, alloc := range sa.getPlaceholderAllocations() {
 					// skip over the allocations that are already marked for release
 					if alloc.IsReleased() {
+						replacing++
+						continue
+					}
+					err := alloc.SetReleased(true)
+					if err != nil {
+						log.Log(log.SchedApplication).Warn("allocation is already preempted, so skipping release process",
+							zap.String("applicationID", sa.ApplicationID),
+							zap.String("allocationKey", alloc.GetAllocationKey()))
+						preempted++
 						continue
 					}
-					alloc.SetReleased(true)
 					toRelease = append(toRelease, alloc)
 				}
+				log.Log(log.SchedApplication).Info("application is getting timed out, releasing allocated placeholders",
+					zap.String("AppID", sa.ApplicationID),
+					zap.Int("replaced", replacing),
+					zap.Int("preempted", preempted),
+					zap.Int("releasing", len(toRelease)))
 				sa.notifyRMAllocationReleased(toRelease, si.TerminationType_TIMEOUT, "releasing placeholders on app complete")
 				sa.clearStateTimer()
 			} else {
@@ -390,19 +410,28 @@ func (sa *Application) timeoutPlaceholderProcessing() {
 		// Case 1: if all app's placeholders are allocated, only part of them gets replaced, just delete the remaining placeholders
 		var toRelease []*Allocation
 		replacing := 0
+		preempted := 0
 		for _, alloc := range sa.getPlaceholderAllocations() {
 			// skip over the allocations that are already marked for release, they will be replaced soon
 			if alloc.IsReleased() {
 				replacing++
 				continue
 			}
-			alloc.SetReleased(true)
+			err := alloc.SetReleased(true)
+			if err != nil {
+				log.Log(log.SchedApplication).Warn("allocation is already preempted, so skipping release process",
+					zap.String("applicationID", sa.ApplicationID),
+					zap.String("allocationKey", alloc.GetAllocationKey()))
+				preempted++
+				continue
+			}
 			toRelease = append(toRelease, alloc)
 		}
 		log.Log(log.SchedApplication).Info("Placeholder timeout, releasing allocated placeholders",
 			zap.String("AppID", sa.ApplicationID),
-			zap.Int("placeholders being replaced", replacing),
-			zap.Int("releasing placeholders", len(toRelease)))
+			zap.Int("replaced", replacing),
+			zap.Int("preempted", preempted),
+			zap.Int("releasing", len(toRelease)))
 		// trigger the release of the placeholders: accounting updates when the release is done
 		sa.notifyRMAllocationReleased(toRelease, si.TerminationType_TIMEOUT, "releasing allocated placeholders on placeholder timeout")
 	} else {
@@ -420,22 +449,38 @@ func (sa *Application) timeoutPlaceholderProcessing() {
 		}
 		// all allocations are placeholders release them all
 		var toRelease, pendingRelease []*Allocation
+		preempted := 0
 		for _, alloc := range sa.allocations {
-			alloc.SetReleased(true)
+			err := alloc.SetReleased(true)
+			if err != nil {
+				log.Log(log.SchedApplication).Warn("allocation is already preempted, so skipping release process",
+					zap.String("applicationID", sa.ApplicationID),
+					zap.String("allocationKey", alloc.GetAllocationKey()))
+				preempted++
+				continue
+			}
 			toRelease = append(toRelease, alloc)
 		}
 		// get all open requests and remove them all filter out already allocated as they are already released
 		for _, alloc := range sa.requests {
 			if !alloc.IsAllocated() {
-				alloc.SetReleased(true)
+				err := alloc.SetReleased(true)
+				if err != nil {
+					log.Log(log.SchedApplication).Warn("allocation is already preempted, so skipping release process",
+						zap.String("applicationID", sa.ApplicationID),
+						zap.String("allocationKey", alloc.GetAllocationKey()))
+					preempted++
+					continue
+				}
 				pendingRelease = append(pendingRelease, alloc)
 				sa.placeholderData[alloc.taskGroupName].TimedOut++
 			}
 		}
 		log.Log(log.SchedApplication).Info("Placeholder timeout, releasing allocated and pending placeholders",
 			zap.String("AppID", sa.ApplicationID),
-			zap.Int("releasing placeholders", len(toRelease)),
-			zap.Int("pending placeholders", len(pendingRelease)),
+			zap.Int("releasing", len(toRelease)),
+			zap.Int("pending", len(pendingRelease)),
+			zap.Int("preempted", preempted),
 			zap.String("gang scheduling style", sa.gangSchedulingStyle))
 		sa.removeAsksInternal("", si.EventRecord_REQUEST_TIMEOUT)
 		// trigger the release of the allocated placeholders: accounting updates when the release is done
@@ -940,11 +985,12 @@ func (sa *Application) canAllocationReserve(alloc *Allocation) error {
 	return nil
 }
 
-func (sa *Application) getOutstandingRequests(headRoom *resources.Resource, userHeadRoom *resources.Resource, total *[]*Allocation) {
+func (sa *Application) getOutstandingRequests(headRoom *resources.Resource, userHeadRoom *resources.Resource, total *[]*Allocation) *resources.Resource {
 	sa.RLock()
 	defer sa.RUnlock()
+	resTotal := resources.NewResource()
 	if sa.sortedRequests == nil {
-		return
+		return resTotal
 	}
 	for _, request := range sa.sortedRequests {
 		if request.IsAllocated() || !request.IsSchedulingAttempted() {
@@ -956,11 +1002,13 @@ func (sa *Application) getOutstandingRequests(headRoom *resources.Resource, user
 			if !request.HasTriggeredScaleUp() && request.requiredNode == common.Empty && !sa.canReplace(request) {
 				// if headroom is still enough for the resources
 				*total = append(*total, request)
+				resTotal.AddTo(request.GetAllocatedResource())
 			}
 			headRoom = resources.SubOnlyExisting(headRoom, request.GetAllocatedResource())
 			userHeadRoom = resources.SubOnlyExisting(userHeadRoom, request.GetAllocatedResource())
 		}
 	}
+	return resTotal
 }
 
 // canReplace returns true if there is a placeholder for the task group available for the request.
@@ -986,8 +1034,18 @@ func (sa *Application) tryAllocate(headRoom *resources.Resource, allowPreemption
 	}
 	// calculate the users' headroom, includes group check which requires the applicationID
 	userHeadroom := ugm.GetUserManager().Headroom(sa.queuePath, sa.ApplicationID, sa.user)
+	unschedulable := uint64(0)
 	// get all the requests from the app sorted in order
 	for _, request := range sa.sortedRequests {
+		backoffThreshold := sa.queue.GetMaxAppUnschedAskBackoff()
+		if backoffThreshold > 0 && unschedulable >= backoffThreshold {
+			log.Log(log.SchedApplication).Info("too many unschedulable asks in the application, waiting",
+				zap.String("application ID", sa.ApplicationID),
+				zap.Uint64("number of unschedulable asks", unschedulable))
+			delay := sa.queue.GetBackoffDelay()
+			sa.backoffDeadline = time.Now().Add(delay)
+			return nil
+		}
 		if request.IsAllocated() {
 			continue
 		}
@@ -1009,11 +1067,10 @@ func (sa *Application) tryAllocate(headRoom *resources.Resource, allowPreemption
 		// resource must fit in headroom otherwise skip the request (unless preemption could help)
 		if !headRoom.FitInMaxUndef(request.GetAllocatedResource()) {
 			// attempt preemption
-			if allowPreemption && *preemptAttemptsRemaining > 0 {
-				*preemptAttemptsRemaining--
+			if allowPreemption {
 				fullIterator := fullNodeIterator()
 				if fullIterator != nil {
-					if result, ok := sa.tryPreemption(headRoom, preemptionDelay, request, fullIterator, false); ok {
+					if result, ok := sa.tryPreemption(headRoom, preemptionDelay, preemptAttemptsRemaining, request, fullIterator, false); ok {
 						// preemption occurred, and possibly reservation
 						return result
 					}
@@ -1046,11 +1103,10 @@ func (sa *Application) tryAllocate(headRoom *resources.Resource, allowPreemption
 			}
 
 			// no nodes qualify, attempt preemption
-			if allowPreemption && *preemptAttemptsRemaining > 0 {
-				*preemptAttemptsRemaining--
+			if allowPreemption {
 				fullIterator := fullNodeIterator()
 				if fullIterator != nil {
-					if result, ok := sa.tryPreemption(headRoom, preemptionDelay, request, fullIterator, true); ok {
+					if result, ok := sa.tryPreemption(headRoom, preemptionDelay, preemptAttemptsRemaining, request, fullIterator, true); ok {
 						// preemption occurred, and possibly reservation
 						return result
 					}
@@ -1058,6 +1114,7 @@ func (sa *Application) tryAllocate(headRoom *resources.Resource, allowPreemption
 				request.LogAllocationFailure(common.PreemptionDoesNotHelp, true)
 			}
 		}
+		unschedulable++
 	}
 	// no requests fit, skip to next app
 	return nil
@@ -1185,9 +1242,15 @@ func (sa *Application) tryPlaceholderAllocate(nodeIterator func() NodeIterator,
 					zap.String("placeholderKey", ph.GetAllocationKey()),
 					zap.Stringer("placeholder resource", ph.GetAllocatedResource()))
 				// release the placeholder and tell the RM
-				ph.SetReleased(true)
-				sa.notifyRMAllocationReleased([]*Allocation{ph}, si.TerminationType_TIMEOUT, "cancel placeholder: resource incompatible")
-				sa.appEvents.SendPlaceholderLargerEvent(ph.taskGroupName, sa.ApplicationID, ph.allocationKey, request.GetAllocatedResource(), ph.GetAllocatedResource())
+				err := ph.SetReleased(true)
+				if err != nil {
+					log.Log(log.SchedApplication).Warn("allocation is already preempted, so skipping placeholder cancellation",
+						zap.String("applicationID", sa.ApplicationID),
+						zap.String("allocationKey", ph.GetAllocationKey()))
+				} else {
+					sa.notifyRMAllocationReleased([]*Allocation{ph}, si.TerminationType_TIMEOUT, "cancel placeholder: resource incompatible")
+					sa.appEvents.SendPlaceholderLargerEvent(ph.taskGroupName, sa.ApplicationID, ph.allocationKey, request.GetAllocatedResource(), ph.GetAllocatedResource())
+				}
 				continue
 			}
 			// placeholder is the same or larger continue processing and difference is handled when the placeholder
@@ -1211,7 +1274,25 @@ func (sa *Application) tryPlaceholderAllocate(nodeIterator func() NodeIterator,
 				// placeholder point to the real one in the releases list
 				ph.SetRelease(request)
 				// mark placeholder as released
-				ph.SetReleased(true)
+				err = ph.SetReleased(true)
+				if err != nil {
+					log.Log(log.SchedApplication).Warn("allocation is already preempted, so not proceeding further and reverting to old state",
+						zap.String("applicationID", sa.ApplicationID),
+						zap.String("allocationKey", ph.GetAllocationKey()))
+
+					// revert: allocate ask
+					_, err = sa.deallocateAsk(request)
+					if err != nil {
+						log.Log(log.SchedApplication).Warn("deallocation of ask failed unexpectedly",
+							zap.Error(err))
+					}
+					// revert: double link to make it easier to find
+					// alloc (the real one) releases points to the placeholder in the releases list
+					request.ClearRelease()
+					// revert: placeholder point to the real one in the releases list
+					ph.ClearRelease()
+					continue
+				}
 				// bind node here so it will be handled properly upon replacement
 				request.SetBindTime(time.Now())
 				request.SetNodeID(node.NodeID)
@@ -1268,7 +1349,34 @@ func (sa *Application) tryPlaceholderAllocate(nodeIterator func() NodeIterator,
 			// placeholder point to the real one in the releases list
 			phFit.SetRelease(reqFit)
 			// mark placeholder as released
-			phFit.SetReleased(true)
+			err = phFit.SetReleased(true)
+
+			if err != nil {
+				log.Log(log.SchedApplication).Warn("allocation is already preempted, so not proceeding further and reverting to old state",
+					zap.String("applicationID", sa.ApplicationID),
+					zap.String("allocationKey", phFit.GetAllocationKey()))
+
+				// revert: node allocation
+				if alloc := node.RemoveAllocation(reqFit.GetAllocationKey()); alloc != nil {
+					log.Log(log.SchedApplication).Debug("Reverting: Node removal failed unexpectedly",
+						zap.String("applicationID", sa.ApplicationID),
+						zap.Stringer("alloc", reqFit))
+				}
+
+				// revert: allocate ask
+				_, err = sa.deallocateAsk(reqFit)
+				if err != nil {
+					log.Log(log.SchedApplication).Warn("deallocation of ask failed unexpectedly",
+						zap.Error(err))
+				}
+				// revert: double link to make it easier to find
+				// alloc (the real one) releases points to the placeholder in the releases list
+				reqFit.ClearRelease()
+				// revert: placeholder point to the real one in the releases list
+				phFit.ClearRelease()
+				return false
+			}
+
 			// bind node here so it will be handled properly upon replacement
 			reqFit.SetBindTime(time.Now())
 			reqFit.SetNodeID(node.NodeID)
@@ -1323,7 +1431,9 @@ func (sa *Application) tryReservedAllocate(headRoom *resources.Resource, nodeIte
 		// Do we need a specific node?
 		if ask.GetRequiredNode() != "" {
 			if !reserve.node.CanAllocate(ask.GetAllocatedResource()) && !ask.HasTriggeredPreemption() {
-				sa.tryRequiredNodePreemption(reserve, ask)
+				// try preemption and see if we can free up resource
+				preemptor := NewRequiredNodePreemptor(reserve.node, ask, sa)
+				preemptor.tryPreemption()
 				continue
 			}
 		}
@@ -1360,7 +1470,15 @@ func (sa *Application) tryReservedAllocate(headRoom *resources.Resource, nodeIte
 	return nil
 }
 
-func (sa *Application) tryPreemption(headRoom *resources.Resource, preemptionDelay time.Duration, ask *Allocation, iterator NodeIterator, nodesTried bool) (*AllocationResult, bool) {
+func (sa *Application) tryPreemption(headRoom *resources.Resource, preemptionDelay time.Duration, preemptionAttemptsRemaining *int, ask *Allocation, iterator NodeIterator, nodesTried bool) (*AllocationResult, bool) {
+	if *preemptionAttemptsRemaining == 0 {
+		log.Log(log.SchedApplication).Debug("Max queue preemption attempts exhausted",
+			zap.String("allocationKey", ask.GetAllocationKey()),
+			zap.String("applicationID", sa.ApplicationID),
+			zap.String("queue", sa.queuePath))
+		ask.LogAllocationFailure(common.PreemptionMaxAttemptsExhausted, true)
+		return nil, false
+	}
 	preemptor := NewPreemptor(sa, headRoom, preemptionDelay, ask, iterator, nodesTried)
 
 	// validate prerequisites for preemption of an ask and mark ask for preemption if successful
@@ -1368,6 +1486,7 @@ func (sa *Application) tryPreemption(headRoom *resources.Resource, preemptionDel
 		ask.LogAllocationFailure(common.PreemptionPreconditionsFailed, true)
 		return nil, false
 	}
+	*preemptionAttemptsRemaining--
 
 	// track time spent trying preemption
 	tryPreemptionStart := time.Now()
@@ -1377,34 +1496,6 @@ func (sa *Application) tryPreemption(headRoom *resources.Resource, preemptionDel
 	return preemptor.TryPreemption()
 }
 
-func (sa *Application) tryRequiredNodePreemption(reserve *reservation, ask *Allocation) bool {
-	// try preemption and see if we can free up resource
-	preemptor := NewRequiredNodePreemptor(reserve.node, ask)
-	preemptor.filterAllocations()
-	preemptor.sortAllocations()
-
-	// Are there any victims/asks to preempt?
-	victims := preemptor.GetVictims()
-	if len(victims) > 0 {
-		log.Log(log.SchedApplication).Info("Found victims for required node preemption",
-			zap.String("ds allocation key", ask.GetAllocationKey()),
-			zap.Int("no.of victims", len(victims)))
-		for _, victim := range victims {
-			if victimQueue := sa.queue.FindQueueByAppID(victim.GetApplicationID()); victimQueue != nil {
-				victimQueue.IncPreemptingResource(victim.GetAllocatedResource())
-			}
-			victim.MarkPreempted()
-		}
-		ask.MarkTriggeredPreemption()
-		sa.notifyRMAllocationReleased(victims, si.TerminationType_PREEMPTED_BY_SCHEDULER,
-			"preempting allocations to free up resources to run daemon set ask: "+ask.GetAllocationKey())
-		return true
-	}
-	ask.LogAllocationFailure(common.NoVictimForRequiredNode, true)
-	ask.SendRequiredNodePreemptionFailedEvent(reserve.node.NodeID)
-	return false
-}
-
 // tryNodesNoReserve tries all the nodes for a reserved request that have not been tried yet.
 // This should never result in a reservation as the allocation is already reserved
 func (sa *Application) tryNodesNoReserve(ask *Allocation, iterator NodeIterator, reservedNode string) *AllocationResult {
@@ -2276,3 +2367,16 @@ func (sa *Application) GetSubmissionTime() time.Time {
 	defer sa.RUnlock()
 	return sa.submissionTime
 }
+
+func (sa *Application) GetBackoffDeadline() time.Time {
+	sa.RLock()
+	defer sa.RUnlock()
+	return sa.backoffDeadline
+}
+
+// SetBackoffDeadline sets the backoff deadline. Only used for testing.
+func (sa *Application) SetBackoffDeadline(deadline time.Time) {
+	sa.Lock()
+	defer sa.Unlock()
+	sa.backoffDeadline = deadline
+}
