@@ -73,7 +73,7 @@ func NewNode(proto *si.NodeInfo) *Node {
 		reservations:      make(map[string]*reservation),
 		totalResource:     resources.NewResourceFromProto(proto.SchedulableResource),
 		allocatedResource: resources.NewResource(),
-		occupiedResource:  resources.NewResourceFromProto(proto.OccupiedResource),
+		occupiedResource:  resources.NewResource(),
 		allocations:       make(map[string]*Allocation),
 		schedulable:       true,
 		listeners:         make([]NodeListener, 0),
@@ -230,14 +230,26 @@ func (sn *Node) GetAllocation(allocationKey string) *Allocation {
 	return sn.allocations[allocationKey]
 }
 
-// Get a copy of the allocations on this node
-func (sn *Node) GetAllAllocations() []*Allocation {
+// GetYunikornAllocations returns a copy of Yunikorn allocations on this node
+func (sn *Node) GetYunikornAllocations() []*Allocation {
 	sn.RLock()
 	defer sn.RUnlock()
+	return sn.getAllocations(false)
+}
 
+// GetForeignAllocations returns a copy of non-Yunikorn allocations on this node
+func (sn *Node) GetForeignAllocations() []*Allocation {
+	sn.RLock()
+	defer sn.RUnlock()
+	return sn.getAllocations(true)
+}
+
+func (sn *Node) getAllocations(foreign bool) []*Allocation {
 	arr := make([]*Allocation, 0)
 	for _, v := range sn.allocations {
-		arr = append(arr, v)
+		if v.IsForeign() == foreign {
+			arr = append(arr, v)
+		}
 	}
 
 	return arr
@@ -312,15 +324,24 @@ func (sn *Node) FitInNode(resRequest *resources.Resource) bool {
 // is found the Allocation removed is returned. Used resources will decrease available
 // will increase as per the allocation removed.
 func (sn *Node) RemoveAllocation(allocationKey string) *Allocation {
-	defer sn.notifyListeners()
+	var alloc *Allocation
+	defer func() {
+		if alloc != nil && !alloc.IsForeign() {
+			sn.notifyListeners()
+		}
+	}()
 	sn.Lock()
 	defer sn.Unlock()
 
-	alloc := sn.allocations[allocationKey]
+	alloc = sn.allocations[allocationKey]
 	if alloc != nil {
 		delete(sn.allocations, allocationKey)
-		sn.allocatedResource.SubFrom(alloc.GetAllocatedResource())
-		sn.allocatedResource.Prune()
+		if alloc.IsForeign() {
+			sn.occupiedResource = resources.Sub(sn.occupiedResource, alloc.GetAllocatedResource())
+		} else {
+			sn.allocatedResource.SubFrom(alloc.GetAllocatedResource())
+			sn.allocatedResource.Prune()
+		}
 		sn.availableResource.AddTo(alloc.GetAllocatedResource())
 		sn.nodeEvents.SendAllocationRemovedEvent(sn.NodeID, alloc.allocationKey, alloc.GetAllocatedResource())
 		log.Log(log.SchedNode).Info("node allocation removed",
@@ -349,14 +370,44 @@ func (sn *Node) AddAllocation(alloc *Allocation) {
 	_ = sn.addAllocationInternal(alloc, true)
 }
 
+// UpdateForeignAllocation updates a foreign allocation and re-calculates the available/occupied resources
+func (sn *Node) UpdateForeignAllocation(alloc *Allocation) *Allocation {
+	sn.Lock()
+	defer sn.Unlock()
+	key := alloc.GetAllocationKey()
+	existing := sn.allocations[key]
+	sn.allocations[key] = alloc
+	if existing == nil {
+		log.Log(log.SchedNode).Debug("unknown allocation to update",
+			zap.String("allocationKey", key))
+		return nil
+	}
+
+	existingResource := existing.GetAllocatedResource().Clone()
+	newResource := alloc.GetAllocatedResource().Clone()
+	delta := resources.Sub(newResource, existingResource)
+	delta.Prune()
+
+	log.Log(log.SchedNode).Info("node foreign allocation updated",
+		zap.String("allocationKey", alloc.GetAllocationKey()),
+		zap.Stringer("deltaResource", delta),
+		zap.String("targetNode", sn.NodeID))
+	sn.occupiedResource.AddTo(delta)
+	sn.occupiedResource.Prune()
+	sn.refreshAvailableResource()
+
+	return existing
+}
+
 func (sn *Node) addAllocationInternal(alloc *Allocation, force bool) bool {
 	if alloc == nil {
 		return false
 	}
 	result := false
+	foreign := alloc.IsForeign()
 	defer func() {
 		// check result to ensure we don't notify listeners unnecessarily
-		if result {
+		if result && !foreign {
 			sn.notifyListeners()
 		}
 	}()
@@ -367,7 +418,11 @@ func (sn *Node) addAllocationInternal(alloc *Allocation, force bool) bool {
 	res := alloc.GetAllocatedResource()
 	if force || sn.availableResource.FitIn(res) {
 		sn.allocations[alloc.GetAllocationKey()] = alloc
-		sn.allocatedResource.AddTo(res)
+		if foreign {
+			sn.occupiedResource = resources.Add(sn.occupiedResource, alloc.GetAllocatedResource())
+		} else {
+			sn.allocatedResource.AddTo(res)
+		}
 		sn.availableResource.SubFrom(res)
 		sn.availableResource.Prune()
 		sn.nodeEvents.SendAllocationAddedEvent(sn.NodeID, alloc.allocationKey, res)
