@@ -54,40 +54,46 @@ type Queue struct {
 	Name      string // Queue name as in the config etc.
 
 	// Private fields need protection
-	sortType            policies.SortPolicy       // How applications (leaf) or queues (parents) are sorted
-	children            map[string]*Queue         // Only for direct children, parent queue only
-	childPriorities     map[string]int32          // cached priorities for child queues
-	applications        map[string]*Application   // only for leaf queue
-	appPriorities       map[string]int32          // cached priorities for application
-	reservedApps        map[string]int            // applications reserved within this queue, with reservation count
-	parent              *Queue                    // link back to the parent in the scheduler
-	pending             *resources.Resource       // pending resource for the apps in the queue
-	allocatedResource   *resources.Resource       // allocated resource for the apps in the queue
-	preemptingResource  *resources.Resource       // preempting resource for the apps in the queue
-	prioritySortEnabled bool                      // whether priority is used for request sorting
-	priorityPolicy      policies.PriorityPolicy   // priority policy
-	priorityOffset      int32                     // priority offset for this queue relative to others
-	preemptionPolicy    policies.PreemptionPolicy // preemption policy
-	preemptionDelay     time.Duration             // time before preemption is considered
-	currentPriority     int32                     // the current scheduling priority of this queue
+	sortType             policies.SortPolicy       // How applications (leaf) or queues (parents) are sorted
+	children             map[string]*Queue         // Only for direct children, parent queue only
+	childPriorities      map[string]int32          // cached priorities for child queues
+	applications         map[string]*Application   // only for leaf queue
+	appPriorities        map[string]int32          // cached priorities for application
+	reservedApps         map[string]int            // applications reserved within this queue, with reservation count
+	parent               *Queue                    // link back to the parent in the scheduler
+	pending              *resources.Resource       // pending resource for the apps in the queue
+	allocatedResource    *resources.Resource       // allocated resource for the apps in the queue
+	preemptingResource   *resources.Resource       // preempting resource for the apps in the queue
+	prioritySortEnabled  bool                      // whether priority is used for request sorting
+	priorityPolicy       policies.PriorityPolicy   // priority policy
+	priorityOffset       int32                     // priority offset for this queue relative to others
+	preemptionPolicy     policies.PreemptionPolicy // preemption policy
+	preemptionDelay      time.Duration             // time delay before preemption is considered
+	quotaPreemptionDelay time.Duration             // time delay before quota preemption is considered
+	currentPriority      int32                     // the current scheduling priority of this queue
 
 	// The queue properties should be treated as immutable the value is a merge of the
 	// parent properties with the config for this queue only manipulated during creation
 	// of the queue or via a queue configuration update.
-	properties             map[string]string
-	adminACL               security.ACL        // admin ACL
-	submitACL              security.ACL        // submit ACL
-	maxResource            *resources.Resource // When not set, max = nil
-	guaranteedResource     *resources.Resource // When not set, Guaranteed == 0
-	isLeaf                 bool                // this is a leaf queue or not (i.e. parent)
-	isManaged              bool                // queue is part of the config, not auto created
-	stateMachine           *fsm.FSM            // the state of the queue for scheduling
-	stateTime              time.Time           // last time the state was updated (needed for cleanup)
-	maxRunningApps         uint64
-	runningApps            uint64
-	allocatingAcceptedApps map[string]bool
-	template               *template.Template
-	queueEvents            *schedEvt.QueueEvents
+	properties               map[string]string
+	adminACL                 security.ACL        // admin ACL
+	submitACL                security.ACL        // submit ACL
+	maxResource              *resources.Resource // When not set, max = nil
+	guaranteedResource       *resources.Resource // When not set, Guaranteed == 0
+	isLeaf                   bool                // this is a leaf queue or not (i.e. parent)
+	isManaged                bool                // queue is part of the config, not auto created
+	stateMachine             *fsm.FSM            // the state of the queue for scheduling
+	stateTime                time.Time           // last time the state was updated (needed for cleanup)
+	maxRunningApps           uint64
+	runningApps              uint64
+	allocatingAcceptedApps   map[string]bool
+	template                 *template.Template
+	queueEvents              *schedEvt.QueueEvents
+	appQueueMapping          *AppQueueMapping // appID mapping to queues
+	quotaPreemptionStartTime time.Time
+	isQuotaPreemptionRunning bool
+	unschedAskBackoff        uint64
+	askBackoffDelay          time.Duration
 
 	locking.RWMutex
 }
@@ -95,31 +101,35 @@ type Queue struct {
 // newBlankQueue creates a new empty queue objects with all values initialised.
 func newBlankQueue() *Queue {
 	return &Queue{
-		children:               make(map[string]*Queue),
-		childPriorities:        make(map[string]int32),
-		applications:           make(map[string]*Application),
-		appPriorities:          make(map[string]int32),
-		reservedApps:           make(map[string]int),
-		allocatingAcceptedApps: make(map[string]bool),
-		properties:             make(map[string]string),
-		stateMachine:           NewObjectState(),
-		allocatedResource:      resources.NewResource(),
-		preemptingResource:     resources.NewResource(),
-		pending:                resources.NewResource(),
-		currentPriority:        configs.MinPriority,
-		prioritySortEnabled:    true,
-		preemptionDelay:        configs.DefaultPreemptionDelay,
-		preemptionPolicy:       policies.DefaultPreemptionPolicy,
+		children:                 make(map[string]*Queue),
+		childPriorities:          make(map[string]int32),
+		applications:             make(map[string]*Application),
+		appPriorities:            make(map[string]int32),
+		reservedApps:             make(map[string]int),
+		allocatingAcceptedApps:   make(map[string]bool),
+		properties:               make(map[string]string),
+		stateMachine:             NewObjectState(),
+		allocatedResource:        resources.NewResource(),
+		preemptingResource:       resources.NewResource(),
+		pending:                  resources.NewResource(),
+		currentPriority:          configs.MinPriority,
+		prioritySortEnabled:      true,
+		preemptionDelay:          configs.DefaultPreemptionDelay,
+		preemptionPolicy:         policies.DefaultPreemptionPolicy,
+		quotaPreemptionDelay:     0,
+		quotaPreemptionStartTime: time.Time{},
+		askBackoffDelay:          configs.DefaultAskBackOffDelay,
 	}
 }
 
 // NewConfiguredQueue creates a new queue from scratch based on the configuration
 // lock free as it cannot be referenced yet.
 // If the silence flag is set to true, the function will neither log the queue creation nor send a queue event.
-func NewConfiguredQueue(conf configs.QueueConfig, parent *Queue, silence bool) (*Queue, error) {
+func NewConfiguredQueue(conf configs.QueueConfig, parent *Queue, silence bool, appQueueMapping *AppQueueMapping) (*Queue, error) {
 	sq := newBlankQueue()
 	sq.Name = strings.ToLower(conf.Name)
 	sq.QueuePath = strings.ToLower(conf.Name)
+	sq.appQueueMapping = appQueueMapping
 	if parent != nil {
 		sq.QueuePath = parent.QueuePath + configs.DOT + sq.Name
 	}
@@ -129,7 +139,7 @@ func NewConfiguredQueue(conf configs.QueueConfig, parent *Queue, silence bool) (
 	sq.updateMaxRunningAppsMetrics()
 
 	// update the properties
-	if err := sq.applyConf(conf, silence); err != nil {
+	if _, err := sq.applyConf(conf, silence); err != nil {
 		return nil, errors.Join(errors.New("configured queue creation failed: "), err)
 	}
 
@@ -138,13 +148,13 @@ func NewConfiguredQueue(conf configs.QueueConfig, parent *Queue, silence bool) (
 	if parent != nil {
 		// pull the properties from the parent that should be set on the child
 		sq.mergeProperties(parent.getProperties(), conf.Properties)
-		sq.UpdateQueueProperties()
+		sq.UpdateQueueProperties(nil)
 		err := parent.addChildQueue(sq)
 		if err != nil {
 			return nil, errors.Join(errors.New("configured queue creation failed: "), err)
 		}
 	} else {
-		sq.UpdateQueueProperties()
+		sq.UpdateQueueProperties(nil)
 	}
 
 	if !silence {
@@ -153,20 +163,19 @@ func NewConfiguredQueue(conf configs.QueueConfig, parent *Queue, silence bool) (
 			zap.String("queueName", sq.QueuePath))
 		sq.queueEvents.SendNewQueueEvent(sq.QueuePath, sq.isManaged)
 	}
-
 	return sq, nil
 }
 
 // NewRecoveryQueue creates a recovery queue if it does not exist. The recovery queue
 // is a dynamic queue, but has an invalid name so that it cannot be directly referenced.
-func NewRecoveryQueue(parent *Queue) (*Queue, error) {
+func NewRecoveryQueue(parent *Queue, appQueueMapping *AppQueueMapping) (*Queue, error) {
 	if parent == nil {
 		return nil, errors.New("recovery queue cannot be created with nil parent")
 	}
 	if parent.GetQueuePath() != configs.RootQueue {
 		return nil, fmt.Errorf("recovery queue cannot be created with non-root parent: %s", parent.GetQueuePath())
 	}
-	queue, err := newDynamicQueueInternal(common.RecoveryQueue, true, parent)
+	queue, err := newDynamicQueueInternal(common.RecoveryQueue, true, parent, appQueueMapping)
 	if err == nil {
 		queue.Lock()
 		defer queue.Unlock()
@@ -179,7 +188,7 @@ func NewRecoveryQueue(parent *Queue) (*Queue, error) {
 // NewDynamicQueue creates a new queue to be added to the system based on the placement rules
 // A dynamically added queue can never be the root queue so parent must be set
 // lock free as it cannot be referenced yet
-func NewDynamicQueue(name string, leaf bool, parent *Queue) (*Queue, error) {
+func NewDynamicQueue(name string, leaf bool, parent *Queue, appQueueMapping *AppQueueMapping) (*Queue, error) {
 	// fail without a parent
 	if parent == nil {
 		return nil, fmt.Errorf("dynamic queue can not be added without parent: %s", name)
@@ -191,16 +200,17 @@ func NewDynamicQueue(name string, leaf bool, parent *Queue) (*Queue, error) {
 	if name == common.RecoveryQueue {
 		return nil, fmt.Errorf("dynamic queue cannot be root.@recovery@")
 	}
-	return newDynamicQueueInternal(name, leaf, parent)
+	return newDynamicQueueInternal(name, leaf, parent, appQueueMapping)
 }
 
-func newDynamicQueueInternal(name string, leaf bool, parent *Queue) (*Queue, error) {
+func newDynamicQueueInternal(name string, leaf bool, parent *Queue, appQueueMapping *AppQueueMapping) (*Queue, error) {
 	sq := newBlankQueue()
 	sq.Name = strings.ToLower(name)
 	sq.QueuePath = parent.QueuePath + configs.DOT + sq.Name
 	sq.parent = parent
 	sq.isManaged = false
 	sq.isLeaf = leaf
+	sq.appQueueMapping = appQueueMapping
 
 	// add to the parent, we might have a partition lock already
 	// still need to make sure we lock the parent so we do not interfere with scheduling
@@ -209,7 +219,7 @@ func newDynamicQueueInternal(name string, leaf bool, parent *Queue) (*Queue, err
 		return nil, errors.Join(errors.New("dynamic queue creation failed: "), err)
 	}
 
-	sq.UpdateQueueProperties()
+	sq.UpdateQueueProperties(nil)
 	sq.queueEvents = schedEvt.NewQueueEvents(events.GetEventSystem())
 	log.Log(log.SchedQueue).Info("dynamic queue added to scheduler",
 		zap.String("queueName", sq.QueuePath))
@@ -262,13 +272,13 @@ func (sq *Queue) mergeProperties(parent, config map[string]string) {
 	}
 }
 
-func preemptionDelay(value string) (time.Duration, error) {
+func convertDelay(value string, def time.Duration) (time.Duration, error) {
 	result, err := time.ParseDuration(value)
 	if err != nil {
-		return configs.DefaultPreemptionDelay, err
+		return def, err
 	}
 	if int64(result) <= int64(0) {
-		return configs.DefaultPreemptionDelay, fmt.Errorf("%s must be positive: %s", configs.PreemptionDelay, value)
+		return def, fmt.Errorf("delay must be positive value: %s", value)
 	}
 	return result, nil
 }
@@ -310,8 +320,16 @@ func filterParentProperty(key string, value string) string {
 	return value
 }
 
+func unschedulableAskBackoff(value string) (uint64, error) {
+	intValue, err := strconv.ParseUint(value, 10, 64)
+	if err != nil {
+		return 0, err
+	}
+	return intValue, nil
+}
+
 // ApplyConf is the locked version of applyConf
-func (sq *Queue) ApplyConf(conf configs.QueueConfig) error {
+func (sq *Queue) ApplyConf(conf configs.QueueConfig) (*resources.Resource, error) {
 	sq.Lock()
 	defer sq.Unlock()
 	return sq.applyConf(conf, false)
@@ -320,20 +338,21 @@ func (sq *Queue) ApplyConf(conf configs.QueueConfig) error {
 // applyConf applies all the properties to the queue from the config.
 // lock free call, must be called holding the queue lock or during create only.
 // If the silence flag is set to true, the function will not log when setting users and groups.
-func (sq *Queue) applyConf(conf configs.QueueConfig, silence bool) error {
+// This function MUST be called holding the lock for the queue.
+func (sq *Queue) applyConf(conf configs.QueueConfig, silence bool) (*resources.Resource, error) {
 	// Set the ACLs
 	var err error
 	sq.submitACL, err = security.NewACL(conf.SubmitACL, silence)
 	if err != nil {
 		log.Log(log.SchedQueue).Error("parsing submit ACL failed this should not happen",
 			zap.Error(err))
-		return err
+		return nil, err
 	}
 	sq.adminACL, err = security.NewACL(conf.AdminACL, silence)
 	if err != nil {
 		log.Log(log.SchedQueue).Error("parsing admin ACL failed this should not happen",
 			zap.Error(err))
-		return err
+		return nil, err
 	}
 	// Change from unmanaged to managed
 	if !sq.isManaged {
@@ -363,21 +382,129 @@ func (sq *Queue) applyConf(conf configs.QueueConfig, silence bool) error {
 
 	if !sq.isLeaf {
 		if err = sq.setTemplate(conf.ChildTemplate); err != nil {
-			return err
+			return nil, err
 		}
 	}
 
+	oldMaxResource := sq.maxResource
 	// Load the max & guaranteed resources and maxApps for all but the root queue
 	if sq.Name != configs.RootQueue {
 		if err = sq.setResourcesFromConf(conf.Resources); err != nil {
-			return err
+			return nil, err
 		}
 		sq.maxRunningApps = conf.MaxApplications
 		sq.updateMaxRunningAppsMetrics()
 	}
-
 	sq.properties = conf.Properties
-	return nil
+	return oldMaxResource, nil
+}
+
+// setPreemptionTime set the time the quota preemption should be triggered when a quota is changed.
+// Updates the time if the delay is set / changes and the preemption is not running yet.
+// This function MUST be called holding the lock for the queue.
+func (sq *Queue) setPreemptionTime(oldMaxResource *resources.Resource, oldDelay time.Duration) {
+	// if quota preemption is running nothing we do not have an influence
+	// if the delay for the queue is not set do not trigger preemption
+	if sq.isQuotaPreemptionRunning || sq.quotaPreemptionDelay == 0 {
+		return
+	}
+	// if no current limit we should not preempt even if it was set earlier, clear the start time
+	if resources.IsZero(sq.maxResource) {
+		sq.quotaPreemptionStartTime = time.Time{}
+		log.Log(log.SchedQueue).Info("removed quota preemption start time",
+			zap.String("queue", sq.QueuePath))
+		return
+	}
+	// adjust the startup based on the diff between the delays if no change
+	if resources.Equals(oldMaxResource, sq.maxResource) {
+		if sq.quotaPreemptionStartTime.IsZero() {
+			// if a delay is set later than the quota change we would like to trigger preemption even if no change for
+			// max resources is detected. preemption trigger will clean up if usage is below max already.
+			if oldDelay == 0 && sq.quotaPreemptionDelay > 0 {
+				sq.quotaPreemptionStartTime = time.Now().Add(sq.quotaPreemptionDelay)
+				log.Log(log.SchedQueue).Info("set quota preemption start time based on delay change",
+					zap.String("queue", sq.QueuePath),
+					zap.Time("quotaPreemptionStartTime", sq.quotaPreemptionStartTime))
+			}
+		} else {
+			if oldDelay != sq.quotaPreemptionDelay {
+				// apply the delta: this can be positive or negative does not matter. The resulting time could be in the
+				// past: also not an issue.
+				sq.quotaPreemptionStartTime = sq.quotaPreemptionStartTime.Add(sq.quotaPreemptionDelay - oldDelay)
+				log.Log(log.SchedQueue).Info("updated quota preemption start time based on delay change",
+					zap.String("queue", sq.QueuePath),
+					zap.Time("quotaPreemptionStartTime", sq.quotaPreemptionStartTime),
+					zap.Duration("delta", sq.quotaPreemptionDelay-oldDelay))
+			}
+		}
+		return
+	}
+	// quota has been lowered, need to set the start time.
+	if resources.StrictlyGreaterThan(oldMaxResource, sq.maxResource) {
+		if !sq.quotaPreemptionStartTime.IsZero() {
+			// multiple consecutive lowering of quotas detected: check for delay change
+			if oldDelay != sq.quotaPreemptionDelay {
+				sq.quotaPreemptionStartTime = sq.quotaPreemptionStartTime.Add(sq.quotaPreemptionDelay - oldDelay)
+				log.Log(log.SchedQueue).Info("consecutive lowering of quota with delay change",
+					zap.String("queue", sq.QueuePath),
+					zap.Time("quotaPreemptionStartTime", sq.quotaPreemptionStartTime),
+					zap.Duration("delta", sq.quotaPreemptionDelay-oldDelay))
+				return
+			}
+			log.Log(log.SchedQueue).Info("consecutive lowering of quota: preemption time already set from earlier quota change",
+				zap.String("queue", sq.QueuePath),
+				zap.Time("quotaPreemptionStartTime", sq.quotaPreemptionStartTime))
+			return
+		}
+		sq.quotaPreemptionStartTime = time.Now().Add(sq.quotaPreemptionDelay)
+		log.Log(log.SchedQueue).Info("Setting quota preemption time",
+			zap.String("queue", sq.QueuePath),
+			zap.Stringer("old maxResource", oldMaxResource),
+			zap.Stringer("maxResources", sq.maxResource),
+			zap.Duration("delay", sq.quotaPreemptionDelay),
+			zap.Time("quotaPreemptionStartTime", sq.quotaPreemptionStartTime))
+	}
+}
+
+// shouldTriggerPreemption returns true if quota preemption should be triggered based on the settings and the
+// current time.
+func (sq *Queue) shouldTriggerPreemption() bool {
+	sq.RLock()
+	defer sq.RUnlock()
+	// dynamic queues do not support quota preemption
+	if !sq.isManaged {
+		return false
+	}
+	// already in progress do not run again
+	if sq.isQuotaPreemptionRunning {
+		return false
+	}
+	// usage is below max: no need to trigger. Happens if the queue drops below the new max when pods stop.
+	// Should clean up, but we have just a read lock...
+	if sq.maxResource.StrictlyGreaterThanOrEqualsOnlyExisting(sq.allocatedResource) {
+		sq.quotaPreemptionStartTime = time.Time{}
+		return false
+	}
+	// trigger if the time is right
+	return !sq.quotaPreemptionStartTime.IsZero() && time.Now().After(sq.quotaPreemptionStartTime)
+}
+
+// setQuotaPreemptionState set or clear the running state for quota preemption. When done the start time is also cleared
+// out preventing a re-run based on the same change
+func (sq *Queue) setQuotaPreemptionState(run bool) {
+	sq.Lock()
+	defer sq.Unlock()
+	if !run {
+		sq.quotaPreemptionStartTime = time.Time{}
+	}
+	sq.isQuotaPreemptionRunning = run
+}
+
+// getQuotaPreemptionRunning returns the running state for quota preemption.
+func (sq *Queue) getQuotaPreemptionRunning() bool {
+	sq.RLock()
+	defer sq.RUnlock()
+	return sq.isQuotaPreemptionRunning
 }
 
 // setResourcesFromConf sets the maxResource and guaranteedResource of the queue from the config.
@@ -485,7 +612,7 @@ func (sq *Queue) setTemplate(conf configs.ChildTemplate) error {
 }
 
 // UpdateQueueProperties updates the queue properties defined as text
-func (sq *Queue) UpdateQueueProperties() {
+func (sq *Queue) UpdateQueueProperties(oldMaxResource *resources.Resource) {
 	sq.Lock()
 	defer sq.Unlock()
 	if common.IsRecoveryQueue(sq.QueuePath) {
@@ -539,12 +666,32 @@ func (sq *Queue) UpdateQueueProperties() {
 			}
 		case configs.PreemptionDelay:
 			if sq.isLeaf {
-				sq.preemptionDelay, err = preemptionDelay(value)
+				sq.preemptionDelay, err = convertDelay(value, configs.DefaultPreemptionDelay)
 				if err != nil {
 					log.Log(log.SchedQueue).Debug("preemption delay property configuration error",
 						zap.Error(err))
 				}
 			}
+		case configs.ApplicationUnschedulableAsksBackoff:
+			sq.unschedAskBackoff, err = unschedulableAskBackoff(value)
+			if err != nil {
+				log.Log(log.SchedQueue).Debug("unschedulable ask backoff configuration error",
+					zap.Error(err))
+			}
+		case configs.ApplicationUnschedulableAsksBackoffDelay:
+			sq.askBackoffDelay, err = convertDelay(value, configs.DefaultAskBackOffDelay)
+			if err != nil {
+				log.Log(log.SchedQueue).Debug("unschedulable ask backoff delay configuration error",
+					zap.Error(err))
+			}
+		case configs.QuotaPreemptionDelay:
+			oldDelay := sq.quotaPreemptionDelay
+			sq.quotaPreemptionDelay, err = convertDelay(value, configs.DefaultQuotaPreemptionDelay)
+			if err != nil {
+				log.Log(log.SchedQueue).Debug("quota preemption delay configuration error",
+					zap.Error(err))
+			}
+			sq.setPreemptionTime(oldMaxResource, oldDelay)
 		default:
 			// skip unknown properties just log them
 			log.Log(log.SchedQueue).Debug("queue property skipped",
@@ -618,7 +765,7 @@ func (sq *Queue) GetPreemptingResource() *resources.Resource {
 func (sq *Queue) GetGuaranteedResource() *resources.Resource {
 	sq.RLock()
 	defer sq.RUnlock()
-	return sq.guaranteedResource
+	return sq.guaranteedResource.Clone()
 }
 
 // GetMaxApps returns the maximum number of applications that can run in this queue.
@@ -628,7 +775,7 @@ func (sq *Queue) GetMaxApps() uint64 {
 	return sq.maxRunningApps
 }
 
-// GetActualGuaranteedResources returns the actual (including parent) guaranteed resources for the queue.
+// GetActualGuaranteedResource returns the actual (including parent) guaranteed resources for the queue.
 func (sq *Queue) GetActualGuaranteedResource() *resources.Resource {
 	if sq == nil {
 		return resources.NewResource()
@@ -710,6 +857,7 @@ func (sq *Queue) GetPartitionQueueDAOInfo(include bool) dao.PartitionQueueDAOInf
 	queueInfo.PreemptionEnabled = sq.preemptionPolicy != policies.DisabledPreemptionPolicy
 	queueInfo.IsPreemptionFence = sq.preemptionPolicy == policies.FencePreemptionPolicy
 	queueInfo.PreemptionDelay = sq.preemptionDelay.String()
+	queueInfo.QuotaPreemptionDelay = sq.quotaPreemptionDelay.String()
 	queueInfo.IsPriorityFence = sq.priorityPolicy == policies.FencePriorityPolicy
 	queueInfo.PriorityOffset = sq.priorityOffset
 	queueInfo.Properties = make(map[string]string)
@@ -1295,6 +1443,12 @@ func (sq *Queue) GetMaxResource() *resources.Resource {
 	return sq.internalGetMax(limit)
 }
 
+func (sq *Queue) cloneMaxResource() *resources.Resource {
+	sq.RLock()
+	defer sq.RUnlock()
+	return sq.maxResource.Clone()
+}
+
 // GetFairMaxResource computes the fair max resources for a given queue.
 // Starting with the root, descend down to the target queue allowing children to override Resource values .
 // If the root includes an explicit 0 value for a Resource, do not include it in the accumulator and treat it as missing.
@@ -1427,7 +1581,25 @@ func (sq *Queue) canRunApp(appID string) bool {
 // resources are skipped.
 // Applications are sorted based on the application sortPolicy. Applications without pending resources are skipped.
 // Lock free call this all locks are taken when needed in called functions
-func (sq *Queue) TryAllocate(iterator func() NodeIterator, fullIterator func() NodeIterator, getnode func(string) *Node, allowPreemption bool) *AllocationResult {
+func (sq *Queue) TryAllocate(iterator func() NodeIterator, fullIterator func() NodeIterator, getnode func(string) *Node, allowPreemption, quotaPreemption bool) *AllocationResult {
+	if quotaPreemption && sq.shouldTriggerPreemption() {
+		go func() {
+			log.Log(log.SchedQueue).Info("Preconditions has passed trigger preemption to enforce new max resources",
+				zap.String("queueName", sq.GetQueuePath()),
+				zap.Stringer("maxResource", sq.cloneMaxResource()))
+			preemptor := NewQuotaPreemptor(sq)
+			preemptor.tryPreemption()
+		}()
+		// when we trigger for a parent queue do not trigger for the children just yet. At least wait until the next
+		// scheduling cycle.
+		quotaPreemption = false
+	}
+	// if quota preemption is running for this queue we do not want to trigger for any of the children.
+	// we do a top-down approach: parent first and when done we check the children
+	// there could be a child quota preemption running already
+	if sq.getQuotaPreemptionRunning() {
+		quotaPreemption = false
+	}
 	if sq.IsLeafQueue() {
 		// get the headroom
 		headRoom := sq.getHeadRoom()
@@ -1442,6 +1614,10 @@ func (sq *Queue) TryAllocate(iterator func() NodeIterator, fullIterator func() N
 			if app.IsAccepted() && (!runnableInQueue || !runnableByUserLimit) {
 				continue
 			}
+			deadline := app.GetBackoffDeadline()
+			if !deadline.IsZero() && time.Now().Before(deadline) {
+				continue
+			}
 			result := app.tryAllocate(headRoom, allowPreemption, preemptionDelay, &preemptAttemptsRemaining, iterator, fullIterator, getnode)
 			if result != nil {
 				log.Log(log.SchedQueue).Info("allocation found on queue",
@@ -1460,7 +1636,7 @@ func (sq *Queue) TryAllocate(iterator func() NodeIterator, fullIterator func() N
 	} else {
 		// process the child queues (filters out queues without pending requests)
 		for _, child := range sq.sortQueues() {
-			result := child.TryAllocate(iterator, fullIterator, getnode, allowPreemption)
+			result := child.TryAllocate(iterator, fullIterator, getnode, allowPreemption, quotaPreemption)
 			if result != nil {
 				return result
 			}
@@ -1501,22 +1677,43 @@ func (sq *Queue) TryPlaceholderAllocate(iterator func() NodeIterator, getnode fu
 	return nil
 }
 
-// GetQueueOutstandingRequests builds a slice of pending allocation asks that fits into the queue's headroom.
-func (sq *Queue) GetQueueOutstandingRequests(total *[]*Allocation) {
+// GetOutstandingRequests builds a slice of pending allocation asks that fits into the queue's headroom.
+// This method can only be called for the root of the queue hierarchy. Otherwise it returns nil.
+func (sq *Queue) GetOutstandingRequests() []*Allocation {
+	total := make([]*Allocation, 0)
+	if sq.parent != nil {
+		return nil
+	}
+
+	for _, child := range sq.sortQueues() {
+		_ = child.getOutStandingRequestsInternal(resources.NewResource(), &total)
+	}
+	return total
+}
+
+func (sq *Queue) getOutStandingRequestsInternal(parentHeadroom *resources.Resource, total *[]*Allocation) *resources.Resource {
+	headRoom := sq.internalHeadRoom(parentHeadroom)
+	outstandingTotal := resources.NewResource() // accumulated resource usage of all collected asks on this level
+
 	if sq.IsLeafQueue() {
-		headRoom := sq.getMaxHeadRoom()
 		// while calculating outstanding requests, we calculate all the requests that can fit into the queue's headroom,
 		// all these requests are qualified to trigger the up scaling.
 		for _, app := range sq.sortApplications(false) {
 			// calculate the users' headroom
 			userHeadroom := ugm.GetUserManager().Headroom(app.queuePath, app.ApplicationID, app.user)
-			app.getOutstandingRequests(headRoom, userHeadroom, total)
+			appTotal := app.getOutstandingRequests(headRoom, userHeadroom, total)
+			outstandingTotal.AddTo(appTotal)
+			headRoom = resources.SubOnlyExisting(headRoom, appTotal)
 		}
 	} else {
 		for _, child := range sq.sortQueues() {
-			child.GetQueueOutstandingRequests(total)
+			queueTotal := child.getOutStandingRequestsInternal(headRoom, total)
+			outstandingTotal.AddTo(queueTotal)
+			headRoom = resources.SubOnlyExisting(headRoom, queueTotal)
 		}
 	}
+
+	return outstandingTotal
 }
 
 // TryReservedAllocate tries to allocate a reservation.
@@ -1625,33 +1822,9 @@ func (sq *Queue) GetApplication(appID string) *Application {
 	return sq.applications[appID]
 }
 
-// FindQueueByAppID searches the queue hierarchy for an application with the given appID and returns the queue it belongs to
-func (sq *Queue) FindQueueByAppID(appID string) *Queue {
-	if sq == nil {
-		return nil
-	}
-	if sq.parent != nil {
-		return sq.parent.FindQueueByAppID(appID)
-	}
-	return sq.findQueueByAppIDInternal(appID)
-}
-
-func (sq *Queue) findQueueByAppIDInternal(appID string) *Queue {
-	if sq == nil {
-		return nil
-	}
-	if sq.IsLeafQueue() {
-		if app := sq.GetApplication(appID); app != nil {
-			return sq
-		}
-		return nil
-	}
-	for _, queue := range sq.GetCopyOfChildren() {
-		if result := queue.findQueueByAppIDInternal(appID); result != nil {
-			return result
-		}
-	}
-	return nil
+// GetQueueByAppID returns the queue that the application with the given appID belongs to
+func (sq *Queue) GetQueueByAppID(appID string) *Queue {
+	return sq.appQueueMapping.GetQueueByAppId(appID)
 }
 
 // getSortType return the queue sort type.
@@ -2059,3 +2232,15 @@ func (sq *Queue) recalculatePriority() int32 {
 	sq.currentPriority = curr
 	return priorityValueByPolicy(sq.priorityPolicy, sq.priorityOffset, curr)
 }
+
+func (sq *Queue) GetMaxAppUnschedAskBackoff() uint64 {
+	sq.RLock()
+	defer sq.RUnlock()
+	return sq.unschedAskBackoff
+}
+
+func (sq *Queue) GetBackoffDelay() time.Duration {
+	sq.RLock()
+	defer sq.RUnlock()
+	return sq.askBackoffDelay
+}
