@@ -65,7 +65,9 @@ type PartitionContext struct {
 	reservations           int                             // number of reservations
 	placeholderAllocations int                             // number of placeholder allocations
 	preemptionEnabled      bool                            // whether preemption is enabled or not
+	quotaPreemptionEnabled bool                            // whether quota preemption is enabled or not
 	foreignAllocs          map[string]*objects.Allocation  // foreign (non-Yunikorn) allocations
+	appQueueMapping        *objects.AppQueueMapping        // appID mapping to queues
 
 	// The partition write lock must not be held while manipulating an application.
 	// Scheduling is running continuously as a lock free background task. Scheduling an application
@@ -96,6 +98,7 @@ func newPartitionContext(conf configs.PartitionConfig, rmID string, cc *ClusterC
 		completedApplications: make(map[string]*objects.Application),
 		nodes:                 objects.NewNodeCollection(conf.Name),
 		foreignAllocs:         make(map[string]*objects.Allocation),
+		appQueueMapping:       objects.NewAppQueueMapping(),
 	}
 	pc.partitionManager = newPartitionManager(pc, cc)
 	if err := pc.initialPartitionFromConfig(conf, silence); err != nil {
@@ -116,7 +119,7 @@ func (pc *PartitionContext) initialPartitionFromConfig(conf configs.PartitionCon
 	// Add the rest of the queue structure recursively
 	queueConf := conf.Queues[0]
 	var err error
-	if pc.root, err = objects.NewConfiguredQueue(queueConf, nil, silence); err != nil {
+	if pc.root, err = objects.NewConfiguredQueue(queueConf, nil, silence, pc.appQueueMapping); err != nil {
 		return err
 	}
 	// recursively add the queues to the root
@@ -134,7 +137,7 @@ func (pc *PartitionContext) initialPartitionFromConfig(conf configs.PartitionCon
 	// Placing an application will not have a lock on the partition context.
 	pc.placementManager = placement.NewPlacementManager(conf.PlacementRules, pc.GetQueue, silence)
 	// get the user group cache for the partition
-	pc.userGroupCache = security.GetUserGroupCache("")
+	pc.userGroupCache = security.GetUserGroupCache(conf.UserGroupResolver, security.GetConfigReader(), security.GetLdapAccess())
 	pc.updateNodeSortingPolicy(conf, silence)
 	pc.updatePreemption(conf)
 
@@ -164,6 +167,7 @@ func (pc *PartitionContext) updateNodeSortingPolicy(conf configs.PartitionConfig
 // NOTE: this is a lock free call. It should only be called holding the PartitionContext lock.
 func (pc *PartitionContext) updatePreemption(conf configs.PartitionConfig) {
 	pc.preemptionEnabled = conf.Preemption.Enabled == nil || *conf.Preemption.Enabled
+	pc.quotaPreemptionEnabled = conf.Preemption.QuotaPreemptionEnabled != nil && *conf.Preemption.QuotaPreemptionEnabled
 }
 
 func (pc *PartitionContext) updatePartitionDetails(conf configs.PartitionConfig) error {
@@ -187,12 +191,12 @@ func (pc *PartitionContext) updatePartitionDetails(conf configs.PartitionConfig)
 	queueConf := conf.Queues[0]
 	root := pc.root
 	// update the root queue
-	if err := root.ApplyConf(queueConf); err != nil {
+	if _, err = root.ApplyConf(queueConf); err != nil {
 		return err
 	}
-	root.UpdateQueueProperties()
+	root.UpdateQueueProperties(nil)
 	// update the rest of the queues recursively
-	if err := pc.updateQueues(queueConf.Queues, root); err != nil {
+	if err = pc.updateQueues(queueConf.Queues, root); err != nil {
 		return err
 	}
 	// update limit settings: start at the root
@@ -204,7 +208,7 @@ func (pc *PartitionContext) updatePartitionDetails(conf configs.PartitionConfig)
 func (pc *PartitionContext) addQueue(conf []configs.QueueConfig, parent *objects.Queue, silence bool) error {
 	// create the queue at this level
 	for _, queueConf := range conf {
-		thisQueue, err := objects.NewConfiguredQueue(queueConf, parent, silence)
+		thisQueue, err := objects.NewConfiguredQueue(queueConf, parent, silence, pc.appQueueMapping)
 		if err != nil {
 			return err
 		}
@@ -232,16 +236,17 @@ func (pc *PartitionContext) updateQueues(config []configs.QueueConfig, parent *o
 		pathName := parentPath + queueConfig.Name
 		queue := pc.getQueueInternal(pathName)
 		var err error
+		var oldMax *resources.Resource
 		if queue == nil {
-			queue, err = objects.NewConfiguredQueue(queueConfig, parent, false)
+			queue, err = objects.NewConfiguredQueue(queueConfig, parent, false, pc.appQueueMapping)
 		} else {
-			err = queue.ApplyConf(queueConfig)
+			oldMax, err = queue.ApplyConf(queueConfig)
 		}
 		if err != nil {
 			return err
 		}
 		// special call to convert to a real policy from the property
-		queue.UpdateQueueProperties()
+		queue.UpdateQueueProperties(oldMax)
 		if err = pc.updateQueues(queueConfig.Queues, queue); err != nil {
 			return err
 		}
@@ -386,6 +391,7 @@ func (pc *PartitionContext) AddApplication(app *objects.Application) error {
 	app.SetTerminatedCallback(pc.moveTerminatedApp)
 	queue.AddApplication(app)
 	pc.applications[appID] = app
+	pc.appQueueMapping.AddAppQueueMapping(appID, queue)
 
 	return nil
 }
@@ -404,6 +410,8 @@ func (pc *PartitionContext) removeApplication(appID string) []*objects.Allocatio
 	if queue := app.GetQueue(); queue != nil {
 		queue.RemoveApplication(app)
 	}
+	// Remove appID mapping
+	pc.appQueueMapping.RemoveAppQueueMapping(appID)
 	// Remove all allocations
 	allocations := app.RemoveAllAllocations()
 	// Remove all allocations from node(s) (queues have been updated already)
@@ -509,7 +517,7 @@ func (pc *PartitionContext) GetPlacementRules() []*dao.RuleDAO {
 
 // createRecoveryQueue creates the recovery queue to add to the hierarchy
 func (pc *PartitionContext) createRecoveryQueue() (*objects.Queue, error) {
-	return objects.NewRecoveryQueue(pc.root)
+	return objects.NewRecoveryQueue(pc.root, pc.appQueueMapping)
 }
 
 // Create a queue with full hierarchy. This is called when a new queue is created from a placement rule.
@@ -543,7 +551,7 @@ func (pc *PartitionContext) createQueue(name string, user security.UserGroup) (*
 	for i := len(toCreate) - 1; i >= 0; i-- {
 		// everything is checked and there should be no errors
 		var err error
-		queue, err = objects.NewDynamicQueue(toCreate[i], i == 0, queue)
+		queue, err = objects.NewDynamicQueue(toCreate[i], i == 0, queue, pc.appQueueMapping)
 		if err != nil {
 			log.Log(log.SchedPartition).Warn("Queue auto create failed unexpected",
 				zap.String("queueName", toCreate[i]),
@@ -800,9 +808,7 @@ func (pc *PartitionContext) calculateOutstandingRequests() []*objects.Allocation
 	if !resources.StrictlyGreaterThanZero(pc.root.GetPendingResource()) {
 		return nil
 	}
-	outstanding := make([]*objects.Allocation, 0)
-	pc.root.GetQueueOutstandingRequests(&outstanding)
-	return outstanding
+	return pc.root.GetOutstandingRequests()
 }
 
 // Try regular allocation for the partition
@@ -813,7 +819,7 @@ func (pc *PartitionContext) tryAllocate() *objects.AllocationResult {
 		return nil
 	}
 	// try allocating from the root down
-	result := pc.root.TryAllocate(pc.GetNodeIterator, pc.GetFullNodeIterator, pc.GetNode, pc.IsPreemptionEnabled())
+	result := pc.root.TryAllocate(pc.GetNodeIterator, pc.GetFullNodeIterator, pc.GetNode, pc.IsPreemptionEnabled(), pc.IsQuotaPreemptionEnabled())
 	if result != nil {
 		return pc.allocate(result)
 	}
@@ -1330,22 +1336,27 @@ func (pc *PartitionContext) handleForeignAllocation(allocationKey, applicationID
 
 	exists := pc.getOrStoreForeignAlloc(alloc)
 	if !exists {
-		log.Log(log.SchedPartition).Info("handling new foreign allocation",
+		log.Log(log.SchedPartition).Info("adding new foreign allocation",
 			zap.String("partitionName", pc.Name),
 			zap.String("nodeID", nodeID),
-			zap.String("allocationKey", allocationKey))
+			zap.String("name", alloc.GetAllocationName()),
+			zap.String("allocationKey", allocationKey),
+			zap.Stringer("allocated resource", alloc.GetAllocatedResource()))
 		node.AddAllocation(alloc)
 		return false, true, nil
 	}
 
-	log.Log(log.SchedPartition).Info("handling foreign allocation update",
+	log.Log(log.SchedPartition).Info("updating foreign allocation",
 		zap.String("partitionName", pc.Name),
 		zap.String("appID", applicationID),
-		zap.String("allocationKey", allocationKey))
+		zap.String("name", alloc.GetAllocationName()),
+		zap.String("allocationKey", allocationKey),
+		zap.Stringer("new allocated resource", alloc.GetAllocatedResource()))
 	prev := node.UpdateForeignAllocation(alloc)
 	if prev == nil {
 		log.Log(log.SchedPartition).Warn("BUG: previous allocation not found during update",
-			zap.String("allocationKey", allocationKey))
+			zap.String("allocationKey", allocationKey),
+			zap.String("name", alloc.GetAllocationName()))
 	}
 
 	return false, false, nil
@@ -1599,11 +1610,13 @@ func (pc *PartitionContext) removeForeignAllocation(allocID string) {
 	node := pc.GetNode(nodeID)
 	if node == nil {
 		log.Log(log.SchedPartition).Debug("Node not found for foreign allocation",
+			zap.String("name", alloc.GetAllocationName()),
 			zap.String("allocationID", allocID),
 			zap.String("nodeID", nodeID))
 		return
 	}
 	log.Log(log.SchedPartition).Info("Removing foreign allocation",
+		zap.String("name", alloc.GetAllocationName()),
 		zap.String("allocationID", allocID),
 		zap.String("nodeID", nodeID))
 	node.RemoveAllocation(allocID)
@@ -1635,6 +1648,12 @@ func (pc *PartitionContext) IsPreemptionEnabled() bool {
 	return pc.preemptionEnabled
 }
 
+func (pc *PartitionContext) IsQuotaPreemptionEnabled() bool {
+	pc.RLock()
+	defer pc.RUnlock()
+	return pc.quotaPreemptionEnabled
+}
+
 func (pc *PartitionContext) moveTerminatedApp(appID string) {
 	app := pc.getApplication(appID)
 	// nothing to do if the app is not found on the partition
