@@ -35,7 +35,7 @@ import (
 	"github.com/julienschmidt/httprouter"
 	"github.com/prometheus/client_golang/prometheus/promhttp"
 	"go.uber.org/zap"
-	"gopkg.in/yaml.v3"
+	"go.yaml.in/yaml/v3"
 
 	"github.com/apache/yunikorn-core/pkg/common"
 	"github.com/apache/yunikorn-core/pkg/common/configs"
@@ -352,6 +352,12 @@ func getApplicationDAO(app *objects.Application) *dao.ApplicationDAOInfo {
 		PlaceholderResource: app.GetTrackedDAOMap("placeholderResource"),
 	}
 
+	backoffDeadline := app.GetBackoffDeadline()
+	var backoffDeadlinePtr *time.Time
+	if !backoffDeadline.IsZero() {
+		backoffDeadlinePtr = &backoffDeadline
+	}
+
 	return &dao.ApplicationDAOInfo{
 		ApplicationID:      app.ApplicationID,
 		UsedResource:       app.GetAllocatedResource().DAOMap(),
@@ -374,6 +380,7 @@ func getApplicationDAO(app *objects.Application) *dao.ApplicationDAOInfo {
 		MaxRequestPriority: app.GetAskMaxPriority(),
 		StartTime:          app.StartTime().UnixMilli(),
 		ResourceHistory:    resHistory,
+		BackoffDeadline:    backoffDeadlinePtr,
 	}
 }
 
@@ -1011,6 +1018,7 @@ func getPartitionInfoDAO(lists map[string]*scheduler.PartitionContext) []*dao.Pa
 		partitionInfo.State = partitionContext.GetCurrentState()
 		partitionInfo.LastStateTransitionTime = partitionContext.GetStateTime().UnixNano()
 		partitionInfo.PreemptionEnabled = partitionContext.IsPreemptionEnabled()
+		partitionInfo.QuotaPreemptionEnabled = partitionContext.IsQuotaPreemptionEnabled()
 
 		capacityInfo := dao.PartitionCapacity{}
 		capacity := partitionContext.GetTotalPartitionResource()
