@@ -25,17 +25,23 @@ import (
 )
 
 type sharedListerImpl struct {
-	nodeInfos framework.NodeInfoLister
+	nodeInfos    framework.NodeInfoLister
+	storageInfos framework.StorageInfoLister
 }
 
 func (s sharedListerImpl) NodeInfos() framework.NodeInfoLister {
 	return s.nodeInfos
 }
 
+func (s sharedListerImpl) StorageInfos() framework.StorageInfoLister {
+	return s.storageInfos
+}
+
 var _ framework.SharedLister = &sharedListerImpl{}
 
 func NewSharedLister(cache *external.SchedulerCache) framework.SharedLister {
 	return &sharedListerImpl{
-		nodeInfos: NewNodeInfoLister(cache),
+		nodeInfos:    NewNodeInfoLister(cache),
+		storageInfos: NewStorageInfoLister(cache),
 	}
 }
