@@ -47,12 +47,12 @@ function verlt() {
 function update_kind_config() {
   # use a different kind config for different cluster versions
   version=$(echo "$1" | sed 's/.*://' | sed 's/^v//')
-  if verlt "${version}" "1.27"; then
-    # 1.26 or earlier
+  if verlt "${version}" "1.32"; then
+    # 1.31 or earlier
     KIND_CONFIG=./scripts/kind.yaml
   else
-    # 1.27 or later; enable InPlacePodVerticalScaling feature flag
-    KIND_CONFIG=./scripts/kind-pod-resize.yaml
+    # 1.32 or later; enable InPlacePodVerticalScaling and PodLevelResources feature flags
+    KIND_CONFIG=./scripts/kind-1.32.yaml
   fi
 }
 
@@ -195,13 +195,14 @@ Examples:
   ${NAME} -a test -n yk8s -v kindest/node:v1.25.16
   ${NAME} -a test -n yk8s -v kindest/node:v1.26.15
   ${NAME} -a test -n yk8s -v kindest/node:v1.27.16
-  ${NAME} -a test -n yk8s -v kindest/node:v1.28.13
-  ${NAME} -a test -n yk8s -v kindest/node:v1.29.8
-  ${NAME} -a test -n yk8s -v kindest/node:v1.30.4
-  ${NAME} -a test -n yk8s -v kindest/node:v1.31.0
+  ${NAME} -a test -n yk8s -v kindest/node:v1.28.15
+  ${NAME} -a test -n yk8s -v kindest/node:v1.29.14
+  ${NAME} -a test -n yk8s -v kindest/node:v1.30.10
+  ${NAME} -a test -n yk8s -v kindest/node:v1.31.6
+  ${NAME} -a test -n yk8s -v kindest/node:v1.32.2
 
   Use a local helm chart path:
-    ${NAME} -a test -n yk8s -v kindest/node:v1.31.0 -p ../yunikorn-release/helm-charts/yunikorn
+    ${NAME} -a test -n yk8s -v kindest/node:v1.32.2 -p ../yunikorn-release/helm-charts/yunikorn
 EOF
 }
 
