@@ -57,15 +57,15 @@ var _ = ginkgo.Describe("", func() {
 		// Wait for pod to move to running state
 		err = kClient.WaitForPodRunning(dev, sleepPodConfigs.Name, 30*time.Second)
 		gomega.Ω(err).NotTo(gomega.HaveOccurred())
-		appsInfo, err = restClient.GetAppInfo("default", "root."+dev, sleepRespPod.ObjectMeta.Labels["applicationId"])
+		appsInfo, err = restClient.GetAppInfo("default", "root."+dev, sleepRespPod.Labels["applicationId"])
 		gomega.Ω(err).NotTo(gomega.HaveOccurred())
 		gomega.Ω(appsInfo).NotTo(gomega.BeNil())
 	})
 
 	ginkgo.It("Verify_App_Queue_Info", func() {
 		ginkgo.By("Verify that the sleep pod is mapped to development queue")
-		gomega.Ω(appsInfo.ApplicationID).To(gomega.Equal(sleepRespPod.ObjectMeta.Labels["applicationId"]))
-		gomega.Ω(appsInfo.QueueName).To(gomega.ContainSubstring(sleepRespPod.ObjectMeta.Namespace))
+		gomega.Ω(appsInfo.ApplicationID).To(gomega.Equal(sleepRespPod.Labels["applicationId"]))
+		gomega.Ω(appsInfo.QueueName).To(gomega.ContainSubstring(sleepRespPod.Namespace))
 	})
 
 	ginkgo.It("Verify_Job_State", func() {
@@ -81,7 +81,7 @@ var _ = ginkgo.Describe("", func() {
 		gomega.Ω(allocation).NotTo(gomega.BeNil())
 		gomega.Ω(allocation.AllocationKey).NotTo(gomega.BeNil())
 		gomega.Ω(allocation.NodeID).NotTo(gomega.BeNil())
-		gomega.Ω(allocation.ApplicationID).To(gomega.Equal(sleepRespPod.ObjectMeta.Labels["applicationId"]))
+		gomega.Ω(allocation.ApplicationID).To(gomega.Equal(sleepRespPod.Labels["applicationId"]))
 		core := sleepRespPod.Spec.Containers[0].Resources.Requests.Cpu().MilliValue()
 		mem := sleepRespPod.Spec.Containers[0].Resources.Requests.Memory().Value()
 		resMap := allocation.ResourcePerAlloc
@@ -103,7 +103,7 @@ var _ = ginkgo.Describe("", func() {
 		gomega.Ω(err).NotTo(gomega.HaveOccurred())
 
 		ginkgo.By("Verify that the pod is scheduled and running")
-		appsInfo, err = restClient.GetAppInfo("default", "root."+dev, bestEffortPod.ObjectMeta.Labels["applicationId"])
+		appsInfo, err = restClient.GetAppInfo("default", "root."+dev, bestEffortPod.Labels["applicationId"])
 		gomega.Ω(err).NotTo(gomega.HaveOccurred())
 		gomega.Ω(appsInfo).NotTo(gomega.BeNil())
 		gomega.Ω(appsInfo.State).To(gomega.Equal("Running"))
@@ -117,7 +117,7 @@ var _ = ginkgo.Describe("", func() {
 		gomega.Ω(allocation).NotTo(gomega.BeNil())
 		gomega.Ω(allocation.AllocationKey).NotTo(gomega.BeNil())
 		gomega.Ω(allocation.NodeID).NotTo(gomega.BeNil())
-		gomega.Ω(allocation.ApplicationID).To(gomega.Equal(bestEffortPod.ObjectMeta.Labels["applicationId"]))
+		gomega.Ω(allocation.ApplicationID).To(gomega.Equal(bestEffortPod.Labels["applicationId"]))
 		core := bestEffortPod.Spec.Containers[0].Resources.Requests.Cpu().MilliValue()
 		mem := bestEffortPod.Spec.Containers[0].Resources.Requests.Memory().Value()
 		resMap := allocation.ResourcePerAlloc
@@ -139,7 +139,7 @@ var _ = ginkgo.Describe("", func() {
 		gomega.Ω(err).NotTo(gomega.HaveOccurred())
 
 		ginkgo.By("Verify that the pod is scheduled and running")
-		appsInfo, err = restClient.GetAppInfo("default", "root."+dev, burstablePod.ObjectMeta.Labels["applicationId"])
+		appsInfo, err = restClient.GetAppInfo("default", "root."+dev, burstablePod.Labels["applicationId"])
 		gomega.Ω(err).NotTo(gomega.HaveOccurred())
 		gomega.Ω(appsInfo).NotTo(gomega.BeNil())
 		gomega.Ω(appsInfo.State).To(gomega.Equal("Running"))
@@ -153,7 +153,7 @@ var _ = ginkgo.Describe("", func() {
 		gomega.Ω(allocation).NotTo(gomega.BeNil())
 		gomega.Ω(allocation.AllocationKey).NotTo(gomega.BeNil())
 		gomega.Ω(allocation.NodeID).NotTo(gomega.BeNil())
-		gomega.Ω(allocation.ApplicationID).To(gomega.Equal(burstablePod.ObjectMeta.Labels["applicationId"]))
+		gomega.Ω(allocation.ApplicationID).To(gomega.Equal(burstablePod.Labels["applicationId"]))
 		core := burstablePod.Spec.Containers[0].Resources.Requests.Cpu().MilliValue()
 		mem := burstablePod.Spec.Containers[0].Resources.Requests.Memory().Value()
 		resMap := allocation.ResourcePerAlloc
