@@ -25,18 +25,18 @@ import { SchedulerService } from '@app/services/scheduler/scheduler.service';
 import { PartitionInfo } from '@app/models/partition-info.model';
 import { MatSelectChange } from '@angular/material/select';
 
-
 @Component({
   selector: 'app-node-utilizations',
   templateUrl: './app-node-utilizations.component.html',
-  styleUrls: ['./app-node-utilizations.component.scss']
+  styleUrls: ['./app-node-utilizations.component.scss'],
+  standalone: false,
 })
 export class AppNodeUtilizationsComponent implements OnInit {
-  private _partitionSelected: string = "";
+  private _partitionSelected: string = '';
   nodeUtilizations: NodeUtilization[] = [];
 
   // input data for vertical bar chart, key is resource type
-  bucketList: string[] = [];                                          // one bucket list for all resource types, length should be exactly 10
+  bucketList: string[] = []; // one bucket list for all resource types, length should be exactly 10
   barChartDataSets: BarChartDataSet[] = new Array<BarChartDataSet>(); // one dataset for each type
   partitionList: PartitionInfo[] = [];
 
@@ -50,28 +50,24 @@ export class AppNodeUtilizationsComponent implements OnInit {
     return this._partitionSelected;
   }
 
-  constructor(
-    private scheduler: SchedulerService
-  ) { }
+  constructor(private scheduler: SchedulerService) {}
 
   ngOnInit() {
-    this.reloadBarChartData()
+    this.reloadBarChartData();
 
-    this.scheduler
-      .fetchPartitionList()
-      .subscribe((list) => {
-        if (list && list.length > 0) {
-          list.forEach((part) => {
-            this.partitionList.push(new PartitionInfo(part.name, part.name));
-          });
+    this.scheduler.fetchPartitionList().subscribe((list) => {
+      if (list && list.length > 0) {
+        list.forEach((part) => {
+          this.partitionList.push(new PartitionInfo(part.name, part.name));
+        });
 
-          this.partitionSelected = CommonUtil.getStoredPartition(list[0].name);
-        } else {
-          this.partitionList = [];
-          this.partitionSelected = '';
-          CommonUtil.setStoredQueueAndPartition('');
-        }
-      });
+        this.partitionSelected = CommonUtil.getStoredPartition(list[0].name);
+      } else {
+        this.partitionList = [];
+        this.partitionSelected = '';
+        CommonUtil.setStoredQueueAndPartition('');
+      }
+    });
   }
 
   onPartitionSelectionChanged(selected: MatSelectChange) {
@@ -80,11 +76,11 @@ export class AppNodeUtilizationsComponent implements OnInit {
 
   reloadBarChartData() {
     this.scheduler.fetchNodeUtilizationsInfo().subscribe((data) => {
-      let nodeUtilizationsInfo: NodeUtilizationsInfo[] = data
+      let nodeUtilizationsInfo: NodeUtilizationsInfo[] = data;
       for (let i = 0; i < nodeUtilizationsInfo.length; i++) {
         if (nodeUtilizationsInfo[i].partition === this.partitionSelected) {
-          let nodeUtilizations = nodeUtilizationsInfo[i].utilizations
-          this.fetchBarChartData(nodeUtilizations)
+          let nodeUtilizations = nodeUtilizationsInfo[i].utilizations;
+          this.fetchBarChartData(nodeUtilizations);
           break;
         }
       }
@@ -100,13 +96,13 @@ export class AppNodeUtilizationsComponent implements OnInit {
     }
 
     let colorMapping = this.generateColorMapping(
-      nodeUtilizations.map((nodeUtilization) => (nodeUtilization.type))
+      nodeUtilizations.map((nodeUtilization) => nodeUtilization.type)
     );
 
     for (let i = 0; i < nodeUtilizations.length; i++) {
       let type = nodeUtilizations[i].type;
-      let utilization = nodeUtilizations[i].utilization
-      let borderWidth = 1
+      let utilization = nodeUtilizations[i].utilization;
+      let borderWidth = 1;
 
       if (i === 0) {
         // get bucketList only from the first type of node utilization
@@ -114,14 +110,16 @@ export class AppNodeUtilizationsComponent implements OnInit {
         this.bucketList = utilization.map((item) => item.bucketName);
       }
       let bucketValues = utilization.map((item) => item.numOfNodes);
-      barChartDataSets.push(new BarChartDataSet(
-        type,
-        bucketValues,
-        this.calculateAvgUtilization(bucketValues),
-        colorMapping.get(type) ?? DEFAULT_BAR_COLOR,
-        borderWidth,
-        utilization.map((item) => this.getBarDescription(item.nodeNames))
-      ))
+      barChartDataSets.push(
+        new BarChartDataSet(
+          type,
+          bucketValues,
+          this.calculateAvgUtilization(bucketValues),
+          colorMapping.get(type) ?? DEFAULT_BAR_COLOR,
+          borderWidth,
+          utilization.map((item) => this.getBarDescription(item.nodeNames))
+        )
+      );
     }
 
     // sort by resource type first, then sort by avg utilization rate
@@ -141,7 +139,8 @@ export class AppNodeUtilizationsComponent implements OnInit {
     // value of nodeCounts[9] means node count of 90%~100%, take 95% as the utilization of node in bucket
     let totalNodes = 0;
     let weightedSum = 0;
-    for (let i = 0; i < 10; i++) { //buckets have fixed length 10
+    for (let i = 0; i < 10; i++) {
+      //buckets have fixed length 10
       if (nodeNumInBuckets[i] != undefined) {
         totalNodes += nodeNumInBuckets[i];
         weightedSum += nodeNumInBuckets[i] * (5 + 10 * i);
@@ -155,9 +154,9 @@ export class AppNodeUtilizationsComponent implements OnInit {
     types.sort();
     let colorMapping = new Map<string, string>();
     for (let i = 0; i < types.length; i++) {
-      colorMapping.set(types[i], CHART_COLORS[i % 10])
+      colorMapping.set(types[i], CHART_COLORS[i % 10]);
     }
-    return colorMapping
+    return colorMapping;
   }
 
   getBarDescription(nodeNames: string[] | null): string {
@@ -165,10 +164,14 @@ export class AppNodeUtilizationsComponent implements OnInit {
     let description: string | undefined;
     if (nodeNames && nodeNames.length > MAX_NODES_IN_DESCRIPTION) {
       // only put MAX_NODES_IN_DESCRIPTION nodes in description, others will be replaced by '...N more'
-      description = nodeNames.slice(0, MAX_NODES_IN_DESCRIPTION).sort().join("\n") + "\n..." + (nodeNames.length - MAX_NODES_IN_DESCRIPTION) + " more";
+      description =
+        nodeNames.slice(0, MAX_NODES_IN_DESCRIPTION).sort().join('\n') +
+        '\n...' +
+        (nodeNames.length - MAX_NODES_IN_DESCRIPTION) +
+        ' more';
     } else {
-      description = nodeNames ? nodeNames.sort().join("\n") : undefined;
+      description = nodeNames ? nodeNames.sort().join('\n') : undefined;
     }
-    return description || ""
+    return description || '';
   }
 }
