@@ -37,7 +37,7 @@ import {
   Filler,
   Legend,
   Title,
-  Tooltip
+  Tooltip,
 } from 'chart.js';
 import 'chartjs-adapter-date-fns';
 
@@ -45,7 +45,7 @@ import { CommonUtil } from '@app/utils/common.util';
 import { AreaDataItem } from '@app/models/area-data.model';
 import { EventBusService, EventMap } from '@app/services/event-bus/event-bus.service';
 import { APP_STATUS_COLOR_MAP } from '@app/utils/constants';
-import * as Color from 'color';
+import Color from 'color';
 
 Chart.register(
   LineElement,
@@ -63,6 +63,7 @@ Chart.register(
   selector: 'app-area-chart',
   templateUrl: './area-chart.component.html',
   styleUrls: ['./area-chart.component.scss'],
+  standalone: false,
 })
 export class AreaChartComponent implements OnInit, AfterViewInit, OnChanges, OnDestroy {
   destroy$ = new Subject<boolean>();
@@ -122,7 +123,7 @@ export class AreaChartComponent implements OnInit, AfterViewInit, OnChanges, OnD
     }
 
     // Filter out negative values from chartData
-    chartData = chartData.filter(item => item.y >= 0);
+    chartData = chartData.filter((item) => item.y >= 0);
 
     this.areaChart = new Chart(ctx!, {
       type: 'line',
@@ -133,7 +134,12 @@ export class AreaChartComponent implements OnInit, AfterViewInit, OnChanges, OnD
             backgroundColor: (context) => {
               const { ctx, chartArea } = context.chart;
               if (!ctx || !chartArea) return;
-              const gradient = ctx.createLinearGradient(0, chartArea.top, 0, chartArea.bottom * 1.2);
+              const gradient = ctx.createLinearGradient(
+                0,
+                chartArea.top,
+                0,
+                chartArea.bottom * 1.2
+              );
 
               gradient.addColorStop(0, Color(APP_STATUS_COLOR_MAP['Running']).alpha(0.4).string());
               gradient.addColorStop(1, 'rgba(255, 255, 255, 0)');
@@ -166,9 +172,9 @@ export class AreaChartComponent implements OnInit, AfterViewInit, OnChanges, OnD
             labels: {
               color: '#666',
               font: {
-                weight: 500
-              }
-            }
+                weight: 500,
+              },
+            },
           },
           title: {
             display: false,
@@ -188,11 +194,11 @@ export class AreaChartComponent implements OnInit, AfterViewInit, OnChanges, OnD
               display: false,
             },
             ticks: {
-              color: '#666'
+              color: '#666',
             },
             border: {
               display: false,
-            }
+            },
           },
           y: {
             ticks: {
@@ -201,12 +207,12 @@ export class AreaChartComponent implements OnInit, AfterViewInit, OnChanges, OnD
             },
             grid: {
               color: '#ccc',
-              tickWidth: 0
+              tickWidth: 0,
             },
             border: {
               display: false,
-              dash: [6, 6]
-            }
+              dash: [6, 6],
+            },
           },
         },
       },
