@@ -17,20 +17,18 @@
  */
 
 import { Component, Input, OnInit } from '@angular/core';
-import { SchedulerHealthInfo } from "@app/models/scheduler-health-info.model";
+import { SchedulerHealthInfo } from '@app/models/scheduler-health-info.model';
 
 @Component({
   selector: 'app-healthchecks',
   templateUrl: './healthchecks.component.html',
-  styleUrls: ['./healthchecks.component.scss']
+  styleUrls: ['./healthchecks.component.scss'],
+  standalone: false,
 })
-
 export class HealthchecksComponent implements OnInit {
-  @Input() schedulerHealth: SchedulerHealthInfo = new SchedulerHealthInfo;
+  @Input() schedulerHealth: SchedulerHealthInfo = new SchedulerHealthInfo();
 
-  constructor() { }
-
-  ngOnInit(): void {
-  }
+  constructor() {}
 
+  ngOnInit(): void {}
 }
