@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-import { AppStatus } from './app-status.model'
+import { AppStatus } from './app-status.model';
 
 export class PartitionInfo {
   name: string;
