@@ -16,14 +16,14 @@
  * limitations under the License.
  */
 
-import {HttpClientTestingModule} from '@angular/common/http/testing';
-import {TestBed} from '@angular/core/testing';
-import {EnvconfigService} from '@app/services/envconfig/envconfig.service';
-import {MockEnvconfigService} from '@app/testing/mocks';
+import { HttpClientTestingModule } from '@angular/common/http/testing';
+import { TestBed } from '@angular/core/testing';
+import { EnvconfigService } from '@app/services/envconfig/envconfig.service';
+import { MockEnvconfigService } from '@app/testing/mocks';
 
-import {SchedulerService} from './scheduler.service';
-import {SchedulerResourceInfo} from '@app/models/resource-info.model';
-import {NOT_AVAILABLE} from '@app/utils/constants';
+import { SchedulerService } from './scheduler.service';
+import { SchedulerResourceInfo } from '@app/models/resource-info.model';
+import { NOT_AVAILABLE } from '@app/utils/constants';
 
 describe('SchedulerService', () => {
   let service: SchedulerService;
@@ -38,7 +38,6 @@ describe('SchedulerService', () => {
 
   it('should create the service', () => {
     expect(service).toBeTruthy();
-    
   });
 
   it('should format SchedulerResourceInfo correctly', () => {
@@ -47,52 +46,54 @@ describe('SchedulerService', () => {
       schedulerResourceInfo: SchedulerResourceInfo;
       expected: string;
     };
-  
+
     const testCases: TestCase[] = [
       {
         description: 'test simple resourceInfo',
         schedulerResourceInfo: {
-          'memory': 1024,
-          'vcore': 2,
+          memory: 1024,
+          vcore: 2,
         },
-        expected: 'Memory: 1 KiB, CPU: 2m'
+        expected: 'Memory: 1 KiB, CPU: 2m',
       },
       {
         description: 'test undefined resourceInfo',
-        schedulerResourceInfo : undefined as any,
-        expected: `${NOT_AVAILABLE}`
+        schedulerResourceInfo: undefined as any,
+        expected: `${NOT_AVAILABLE}`,
       },
       {
         description: 'test empty resourceInfo',
-        schedulerResourceInfo : {} as any,
-        expected: `${NOT_AVAILABLE}`
+        schedulerResourceInfo: {} as any,
+        expected: `${NOT_AVAILABLE}`,
       },
       {
         description: 'Test zero values',
         schedulerResourceInfo: {
-          'memory': 0,
-          'vcore': 0,
+          memory: 0,
+          vcore: 0,
           'ephemeral-storage': 0,
           'hugepages-2Mi': 0,
           'hugepages-1Gi': 0,
-          'pods': 0
+          pods: 0,
         },
-        expected: 'Memory: 0 B, CPU: 0, pods: 0, ephemeral-storage: 0 B, hugepages-1Gi: 0 B, hugepages-2Mi: 0 B'
+        expected:
+          'Memory: 0 B, CPU: 0, pods: 0, ephemeral-storage: 0 B, hugepages-1Gi: 0 B, hugepages-2Mi: 0 B',
       },
       {
         description: 'Test resource ordering',
         schedulerResourceInfo: {
           'ephemeral-storage': 2048,
-          'memory': 1024,
-          'vcore': 2,
-          'TPU': 30000,
-          'GPU': 40000,
-          'hugepages-2Mi':2097152,
-          'hugepages-1Gi':1073741824,
-          'pods': 10000
+          memory: 1024,
+          vcore: 2,
+          TPU: 30000,
+          GPU: 40000,
+          'hugepages-2Mi': 2097152,
+          'hugepages-1Gi': 1073741824,
+          pods: 10000,
         },
-        expected: 'Memory: 1 KiB, CPU: 2m, pods: 10k, ephemeral-storage: 2.05 kB, GPU: 40k, hugepages-1Gi: 1 GiB, hugepages-2Mi: 2 MiB, TPU: 30k'
-      }
+        expected:
+          'Memory: 1 KiB, CPU: 2m, pods: 10k, ephemeral-storage: 2.05 kB, GPU: 40k, hugepages-1Gi: 1 GiB, hugepages-2Mi: 2 MiB, TPU: 30k',
+      },
     ];
 
     testCases.forEach((testCase: TestCase) => {
@@ -101,43 +102,42 @@ describe('SchedulerService', () => {
     });
   });
 
-
   it('should format SchedulerResourceInfo percentage correctly', () => {
     type TestCase = {
       description: string;
       schedulerResourceInfo: SchedulerResourceInfo;
       expected: string;
     };
-  
+
     const testCases: TestCase[] = [
       {
         description: 'test simple resourceInfo',
         schedulerResourceInfo: {
-          'memory': 10,
-          'vcore': 50,
+          memory: 10,
+          vcore: 50,
         },
-        expected: 'Memory: 10%, CPU: 50%'
+        expected: 'Memory: 10%, CPU: 50%',
       },
       {
         description: 'test undefined resourceInfo',
-        schedulerResourceInfo : undefined as any,
-        expected: `${NOT_AVAILABLE}`
+        schedulerResourceInfo: undefined as any,
+        expected: `${NOT_AVAILABLE}`,
       },
       {
         description: 'test empty resourceInfo',
-        schedulerResourceInfo : {} as any,
-        expected: `${NOT_AVAILABLE}`
+        schedulerResourceInfo: {} as any,
+        expected: `${NOT_AVAILABLE}`,
       },
       {
         description: 'Test zero values and will only show memory and cpu',
         schedulerResourceInfo: {
-          'memory': 0,
-          'vcore': 0,
-          'pods': 0,
+          memory: 0,
+          vcore: 0,
+          pods: 0,
           'ephemeral-storage': 0,
         },
-        expected: 'Memory: 0%, CPU: 0%'
-      }
+        expected: 'Memory: 0%, CPU: 0%',
+      },
     ];
 
     testCases.forEach((testCase: TestCase) => {
