@@ -16,30 +16,33 @@
  * limitations under the License.
  */
 
-import {HttpClient} from '@angular/common/http';
-import {Injectable} from '@angular/core';
-import {AllocationInfo} from '@app/models/alloc-info.model';
-import {AppInfo} from '@app/models/app-info.model';
-import {ClusterInfo} from '@app/models/cluster-info.model';
-import {HistoryInfo} from '@app/models/history-info.model';
-import {NodeInfo} from '@app/models/node-info.model';
-import {NodeUtilizationsInfo} from '@app/models/node-utilization.model';
-import {Partition} from '@app/models/partition-info.model';
+import { HttpClient } from '@angular/common/http';
+import { Injectable } from '@angular/core';
+import { AllocationInfo } from '@app/models/alloc-info.model';
+import { AppInfo } from '@app/models/app-info.model';
+import { ClusterInfo } from '@app/models/cluster-info.model';
+import { HistoryInfo } from '@app/models/history-info.model';
+import { NodeInfo } from '@app/models/node-info.model';
+import { NodeUtilizationsInfo } from '@app/models/node-utilization.model';
+import { Partition } from '@app/models/partition-info.model';
 
-import {QueueInfo, QueuePropertyItem} from '@app/models/queue-info.model';
-import {SchedulerResourceInfo} from '@app/models/resource-info.model';
-import {SchedulerHealthInfo} from "@app/models/scheduler-health-info.model";
-import {CommonUtil} from '@app/utils/common.util';
-import {NOT_AVAILABLE} from '@app/utils/constants';
-import {Observable} from 'rxjs';
-import {map} from 'rxjs/operators';
-import {EnvconfigService} from '../envconfig/envconfig.service';
+import { QueueInfo, QueuePropertyItem } from '@app/models/queue-info.model';
+import { SchedulerResourceInfo } from '@app/models/resource-info.model';
+import { SchedulerHealthInfo } from '@app/models/scheduler-health-info.model';
+import { CommonUtil } from '@app/utils/common.util';
+import { NOT_AVAILABLE } from '@app/utils/constants';
+import { Observable } from 'rxjs';
+import { map } from 'rxjs/operators';
+import { EnvconfigService } from '../envconfig/envconfig.service';
 
 @Injectable({
   providedIn: 'root',
 })
 export class SchedulerService {
-  constructor(private httpClient: HttpClient, private envConfig: EnvconfigService) {}
+  constructor(
+    private httpClient: HttpClient,
+    private envConfig: EnvconfigService
+  ) {}
 
   fetchClusterList(): Observable<ClusterInfo[]> {
     const clusterUrl = `${this.envConfig.getSchedulerWebAddress()}/ws/v1/clusters`;
@@ -101,8 +104,8 @@ export class SchedulerService {
               app['applicationState'],
               []
             );
-            appInfo.setLastStateChangeTime()
-            
+            appInfo.setLastStateChangeTime();
+
             const allocations = app['allocations'];
             if (allocations && allocations.length > 0) {
               const appAllocations: AllocationInfo[] = [];
@@ -113,9 +116,8 @@ export class SchedulerService {
                   alloc.allocationTags['kubernetes.io/meta/namespace'] &&
                   alloc.allocationTags['kubernetes.io/meta/podName']
                 ) {
-                  alloc[
-                    'displayName'
-                  ] = `${alloc.allocationTags['kubernetes.io/meta/namespace']}/${alloc.allocationTags['kubernetes.io/meta/podName']}`;
+                  alloc['displayName'] =
+                    `${alloc.allocationTags['kubernetes.io/meta/namespace']}/${alloc.allocationTags['kubernetes.io/meta/podName']}`;
                 } else {
                   alloc['displayName'] = `<nil>`;
                 }
@@ -205,7 +207,7 @@ export class SchedulerService {
               this.formatResource(node['available'] as SchedulerResourceInfo),
               this.formatPercent(node['utilized'] as SchedulerResourceInfo),
               [],
-              node['attributes'],
+              node['attributes']
             );
 
             const ykAllocations = node['allocations'];
@@ -218,9 +220,8 @@ export class SchedulerService {
                   alloc.allocationTags['kubernetes.io/meta/namespace'] &&
                   alloc.allocationTags['kubernetes.io/meta/podName']
                 ) {
-                  alloc[
-                    'displayName'
-                  ] = `${alloc.allocationTags['kubernetes.io/meta/namespace']}/${alloc.allocationTags['kubernetes.io/meta/podName']}`;
+                  alloc['displayName'] =
+                    `${alloc.allocationTags['kubernetes.io/meta/namespace']}/${alloc.allocationTags['kubernetes.io/meta/podName']}`;
                 } else {
                   alloc['displayName'] = '<nil>';
                 }
@@ -243,15 +244,14 @@ export class SchedulerService {
 
             const foreignAllocations = node['foreignAllocations'];
             if (foreignAllocations && foreignAllocations.length > 0) {
-	      foreignAllocations.forEach((alloc: any) => {
+              foreignAllocations.forEach((alloc: any) => {
                 if (
                   alloc.allocationTags &&
                   alloc.allocationTags['kubernetes.io/meta/namespace'] &&
                   alloc.allocationTags['kubernetes.io/meta/podName']
                 ) {
-                  alloc[
-                    'displayName'
-                  ] = `${alloc.allocationTags['kubernetes.io/meta/namespace']}/${alloc.allocationTags['kubernetes.io/meta/podName']}`;
+                  alloc['displayName'] =
+                    `${alloc.allocationTags['kubernetes.io/meta/namespace']}/${alloc.allocationTags['kubernetes.io/meta/podName']}`;
                 } else {
                   alloc['displayName'] = '<nil>';
                 }
@@ -263,9 +263,9 @@ export class SchedulerService {
                     alloc['allocationTags'],
                     this.formatResource(alloc['resource'] as SchedulerResourceInfo),
                     alloc['priority'],
-                    "n/a",
+                    'n/a',
                     alloc['nodeId'],
-                    "n/a",
+                    'n/a',
                     alloc['partition']
                   )
                 );
@@ -284,14 +284,18 @@ export class SchedulerService {
     );
   }
 
-  fetchNodeUtilizationsInfo(): Observable<NodeUtilizationsInfo[]>{
+  fetchNodeUtilizationsInfo(): Observable<NodeUtilizationsInfo[]> {
     const nodeUtilizationsUrl = `${this.envConfig.getSchedulerWebAddress()}/ws/v1/scheduler/node-utilizations`;
-    return this.httpClient.get(nodeUtilizationsUrl).pipe(map((data: any) => data as NodeUtilizationsInfo[]));
+    return this.httpClient
+      .get(nodeUtilizationsUrl)
+      .pipe(map((data: any) => data as NodeUtilizationsInfo[]));
   }
 
   fecthHealthchecks(): Observable<SchedulerHealthInfo> {
     const healthCheckUrl = `${this.envConfig.getSchedulerWebAddress()}/ws/v1/scheduler/healthcheck`;
-    return this.httpClient.get(healthCheckUrl).pipe(map((data: any) => data as SchedulerHealthInfo));
+    return this.httpClient
+      .get(healthCheckUrl)
+      .pipe(map((data: any) => data as SchedulerHealthInfo));
   }
 
   private generateQueuesTree(data: any, currentQueue: QueueInfo) {
@@ -358,49 +362,51 @@ export class SchedulerService {
     const formatted: string[] = [];
     if (resource) {
       // Object.keys() didn't guarantee the order of keys, sort it before iterate.
-      Object.keys(resource).sort(CommonUtil.resourcesCompareFn).forEach((key) => {
-        let value = resource[key];
-        let formattedKey = key;
-        let formattedValue : string;
+      Object.keys(resource)
+        .sort(CommonUtil.resourcesCompareFn)
+        .forEach((key) => {
+          let value = resource[key];
+          let formattedKey = key;
+          let formattedValue: string;
 
-        switch(key){
-          case "memory":
-            formattedKey = "Memory";
-            formattedValue = CommonUtil.formatMemoryBytes(value);
-            break;
-          case "vcore":
-            formattedKey = "CPU";
-            formattedValue = CommonUtil.formatCpuCore(value);
-            break;
-          case "ephemeral-storage":
-            formattedValue = CommonUtil.formatEphemeralStorageBytes(value);
-            break;
-          default:
-            if (key.startsWith('hugepages-')) {
+          switch (key) {
+            case 'memory':
+              formattedKey = 'Memory';
               formattedValue = CommonUtil.formatMemoryBytes(value);
-            } else{
-              formattedValue = CommonUtil.formatOtherResource(value);
-            }
-            break;
-         }
-        formatted.push(`${formattedKey}: ${formattedValue}`);
-      });
+              break;
+            case 'vcore':
+              formattedKey = 'CPU';
+              formattedValue = CommonUtil.formatCpuCore(value);
+              break;
+            case 'ephemeral-storage':
+              formattedValue = CommonUtil.formatEphemeralStorageBytes(value);
+              break;
+            default:
+              if (key.startsWith('hugepages-')) {
+                formattedValue = CommonUtil.formatMemoryBytes(value);
+              } else {
+                formattedValue = CommonUtil.formatOtherResource(value);
+              }
+              break;
+          }
+          formatted.push(`${formattedKey}: ${formattedValue}`);
+        });
     }
 
     if (formatted.length === 0) {
       return NOT_AVAILABLE;
     }
     return formatted.join(', ');
-  } 
+  }
 
   private formatPercent(resource: SchedulerResourceInfo): string {
     const formatted = [];
 
     if (resource) {
-      if (resource.memory !== undefined){
+      if (resource.memory !== undefined) {
         formatted.push(`Memory: ${CommonUtil.formatPercent(resource.memory)}`);
       }
-      if (resource.vcore !== undefined){
+      if (resource.vcore !== undefined) {
         formatted.push(`CPU: ${CommonUtil.formatPercent(resource.vcore)}`);
       }
     }
